import mxupy as mu
from bigOAINet.db.data.m.County import County

class CountyControl(mu.EntityXControl):
    class Meta:
        model_class = County
    
    def get_id(self, name):
        """
        获取编号

        参数:
            name (str): 区名称

        返回:
            int: 区编号，如果未找到则返回-1
        """
        def _do(im):
            mc = self.model_class
            im.data = -1
            im.data = mc.get(mc.name.contains(name)).countyId

        return self.run(_do)

    def add_county(self, id, cityId, name, enname):
        """
        添加（用于初始化数据）

        参数:
            id (int): 区域id
            cityId (int): 城市id
            name (str): 名称
            enName (str): 英文名称

        返回:
            IM: 返回操作结果
        """
        def _do(im):
            
            mc = self.model_class
            
            if mc.select().where(mc.countyId == id).exists():
                im.success = False
                im.msg = f'已经存在 countyId 为 {id} 的记录。'
                return
            
            c = {
                'countyId':id,
                'cityId':cityId,
                'name':name,
                'enname':enname
            }    
            im.data = mc.create(**c)

        return self.run(_do)
    
    
    def init_data(self):
        """
        初始化数据

        参数:

        返回:
            IM: 返回操作结果
        """
        
        cs = [
            (1414, 1369, "东城区", "Dongcheng"),
            (1415, 1369, "西城区", "Xicheng"),
            (1416, 1369, "崇文区", "Chongwen"),
            (1417, 1369, "宣武区", "Xuanwu"),
            (1418, 1369, "朝阳区", "Chaoyang"),
            (1419, 1369, "海淀区", "Haidian"),
            (1420, 1369, "丰台区", "Fengtai"),
            (1421, 1369, "石景山区", "Shijingshan"),
            (1422, 1369, "房山区", "Fangshan"),
            (1423, 1369, "通州区", "Tongzhou"),
            (1424, 1369, "顺义区", "Shunyi"),
            (1425, 1369, "门头沟区", "Mentougou"),
            (1426, 1369, "昌平区", "Changping"),
            (1427, 1369, "大兴区", "Daxing"),
            (1428, 1369, "怀柔区", "Huairou"),
            (1429, 1369, "平谷区", "Pinggu"),
            (1430, 1369, "密云县", "Miyun"),
            (1431, 1369, "延庆县", "Yanqing"),
            (1432, 1371, "和平区", "Heping"),
            (1433, 1371, "河东区", "Hedong"),
            (1434, 1371, "河西区", "Hexi"),
            (1435, 1371, "南开区", "Nankai"),
            (1436, 1371, "河北区", "Hebei"),
            (1437, 1371, "红桥区", "Hongqiao"),
            (1438, 1371, "塘沽区", "Tanggu"),
            (1439, 1371, "汉沽区", "Hangu"),
            (1440, 1371, "大港区", "Dagang"),
            (1441, 1371, "东丽区", "Dongli"),
            (1442, 1371, "西青区", "Xiqing"),
            (1443, 1371, "北辰区", "Beichen"),
            (1444, 1371, "津南区", "Jinnan"),
            (1445, 1371, "武清区", "Wuqing"),
            (1446, 1371, "宝坻区", "Baodi"),
            (1447, 1371, "静海县", "Jinghai"),
            (1448, 1371, "宁河县", "Ninghe"),
            (1449, 1371, "蓟县", "Jixian"),
            (1450, 1370, "黄浦区", "Huangpu"),
            (1451, 1370, "卢湾区", "Luwan"),
            (1452, 1370, "徐汇区", "Xuhui"),
            (1453, 1370, "长宁区", "Changning"),
            (1454, 1370, "静安区", "Jingan"),
            (1455, 1370, "普陀区", "Putuo"),
            (1456, 1370, "闸北区", "Zhabei"),
            (1457, 1370, "虹口区", "Hongkou"),
            (1458, 1370, "杨浦区", "Yangpu"),
            (1459, 1370, "宝山区", "Baoshan"),
            (1460, 1370, "闵行区", "Minxing"),
            (1461, 1370, "嘉定区", "Jiading"),
            (1462, 1370, "松江区", "Songjiang"),
            (1463, 1370, "金山区", "Jinshan"),
            (1464, 1370, "青浦区", "Qingpu"),
            (1465, 1370, "浦东新区", "Pudong"),
            (1466, 1370, "南汇区", "Nanhui"),
            (1467, 1370, "奉贤区", "Fengxian"),
            (1468, 1370, "崇明县", "Chongming"),
            (1469, 1372, "渝中区", "Yuzhong"),
            (1470, 1372, "大渡口区", "Dadukou"),
            (1471, 1372, "江北区", "Jiangbei"),
            (1472, 1372, "沙坪坝区", "Shapingba"),
            (1473, 1372, "九龙坡区", "Jiulongpo"),
            (1474, 1372, "南岸区", "Nanan"),
            (1475, 1372, "北碚区", "Beibei"),
            (1476, 1372, "万盛区", "Wansheng"),
            (1477, 1372, "双桥区", "Shuangqiao"),
            (1478, 1372, "渝北区", "Yubei"),
            (1479, 1372, "巴南区", "Banan"),
            (1480, 1372, "万州区", "Wanzhou"),
            (1481, 1372, "涪陵区", "Fuling"),
            (1482, 1372, "黔江区", "Qianjiang"),
            (1483, 1372, "长寿区", "Changshou"),
            (1484, 1372, "永川市", "Yongzhou"),
            (1485, 1372, "合川市", "Hezhou"),
            (1486, 1372, "江津市", "Jiangjin"),
            (1487, 1372, "南川市", "Nanchuan"),
            (1488, 1372, "綦江县", "Qijiang"),
            (1489, 1372, "潼南县", "Tongnan"),
            (1490, 1372, "荣昌县", "Rongchang"),
            (1491, 1372, "璧山县", "Bishan"),
            (1492, 1372, "大足县", "Dazu"),
            (1493, 1372, "铜梁县", "Tongliang"),
            (1494, 1372, "梁平县", "Liangping"),
            (1495, 1372, "城口县", "Chengkou"),
            (1496, 1372, "垫江县", "Dianjiang"),
            (1497, 1372, "武隆县", "Wulong"),
            (1498, 1372, "丰都县", "Fengdu"),
            (1499, 1372, "奉节县", "Fengjie"),
            (1500, 1372, "开县", "Kaixian"),
            (1501, 1372, "云阳县", "Yunyang"),
            (1502, 1372, "忠县", "Zhongxian"),
            (1503, 1372, "巫溪县", "Wuxi"),
            (1504, 1372, "巫山县", "Wushan"),
            (1505, 1372, "石柱土家族自治县", "Shizhu"),
            (1506, 1372, "秀山土家族苗族自治县", "Xiushan"),
            (1507, 1372, "酉阳土家族苗族自治县", "Youyang"),
            (1508, 1372, "彭水苗族土家族自治县", "Pengshui"),
            (1509, 1124, "长安区", "Changan"),
            (1510, 1124, "桥东区", "Qiaodong"),
            (1511, 1124, "桥西区", "Qiaoxi"),
            (1512, 1124, "新华区", "Xinhua"),
            (1513, 1124, "裕华区", "Yuhua"),
            (1514, 1124, "井陉矿区", "Jingxing Mining Area"),
            (1515, 1124, "辛集市", "Xinji"),
            (1516, 1124, "藁城市", "Gaocheng"),
            (1517, 1124, "晋州市", "Jinzhou"),
            (1518, 1124, "新乐市", "Xinle"),
            (1519, 1124, "鹿泉市", "Luquan"),
            (1520, 1124, "平山县", "Pingshan"),
            (1521, 1124, "井陉县", "Jingxing"),
            (1522, 1124, "栾城县", "Luancheng"),
            (1523, 1124, "正定县", "Zhengding"),
            (1524, 1124, "行唐县", "Xingtang"),
            (1525, 1124, "灵寿县", "Lingshou"),
            (1526, 1124, "高邑县", "Gaoyi"),
            (1527, 1124, "赵县", "Zhaoxian"),
            (1528, 1124, "赞皇县", "Zanhuang"),
            (1529, 1124, "深泽县", "Shenze"),
            (1530, 1124, "无极县", "Wuji"),
            (1531, 1124, "元氏县", "Yuanshi"),
            (1532, 1125, "路北区", "Lubei"),
            (1533, 1125, "路南区", "Lunan"),
            (1534, 1125, "古冶区", "Guzhi"),
            (1535, 1125, "开平区", "Kaiping"),
            (1536, 1125, "丰南区", "Fengnan"),
            (1537, 1125, "丰润区", "Fengrun"),
            (1538, 1125, "遵化市", "Zunhua"),
            (1539, 1125, "迁安市", "Qianan"),
            (1540, 1125, "迁西县", "Qianxi"),
            (1541, 1125, "滦南县", "Luannan"),
            (1542, 1125, "玉田县", "Yutian"),
            (1543, 1125, "唐海县", "Tanghai"),
            (1544, 1125, "乐亭县", "Leting"),
            (1545, 1125, "滦县", "Luanxian"),
            (1546, 1122, "海港区", "Hanggang"),
            (1547, 1122, "山海关区", "Shanhaiguan"),
            (1548, 1122, "北戴河区", "Beidaihe"),
            (1549, 1122, "昌黎县", "Changli"),
            (1550, 1122, "卢龙县", "Lulong"),
            (1551, 1122, "抚宁县", "Funing"),
            (1552, 1122, "青龙满族自治县", "Qinglong"),
            (1553, 1131, "从台区", "Congtai"),
            (1554, 1131, "复兴区", "Fuxing"),
            (1555, 1131, "邯山区", "Hanshan"),
            (1556, 1131, "峰峰矿区", "Fengfeng Mining Area"),
            (1557, 1131, "武安市", "Wuan"),
            (1558, 1131, "邯郸县", "Handan"),
            (1559, 1131, "永年县", "Yongnian"),
            (1560, 1131, "曲周县", "Quzhou"),
            (1561, 1131, "馆陶县", "Guantao"),
            (1562, 1131, "魏县", "Weixian"),
            (1563, 1131, "成安县", "Chengan"),
            (1564, 1131, "大名县", "Daming"),
            (1565, 1131, "涉县", "Shexian"),
            (1566, 1131, "鸡泽县", "Jize"),
            (1567, 1131, "邱县", "Qiuxian"),
            (1568, 1131, "广平县", "Guangping"),
            (1569, 1131, "肥乡县", "Feixiang"),
            (1570, 1131, "临漳县", "Linzhang"),
            (1571, 1131, "磁县", "Cixian"),
            (1572, 1123, "桥东区", "Qiaodong"),
            (1573, 1123, "桥西区", "Qiaoxi"),
            (1574, 1123, "南宫市", "Nangong"),
            (1575, 1123, "沙河市", "Shahe"),
            (1576, 1123, "邢台县", "Xingtai"),
            (1577, 1123, "柏乡县", "Baixiang"),
            (1578, 1123, "任县", "Renxian"),
            (1579, 1123, "清河县", "Qinghe"),
            (1580, 1123, "宁晋县", "Ningjin"),
            (1581, 1123, "威县", "Weixian"),
            (1582, 1123, "隆尧县", "Longyao"),
            (1583, 1123, "临城县", "Lincheng"),
            (1584, 1123, "广宗县", "Guangzong"),
            (1585, 1123, "临西县", "Linxi"),
            (1586, 1123, "内丘县", "Neiqiu"),
            (1587, 1123, "平乡县", "Pingxiang"),
            (1588, 1123, "巨鹿县", "Julu"),
            (1589, 1123, "新河县", "Xinhe"),
            (1590, 1123, "南和县", "Nanhe"),
            (1591, 1127, "新市区", "Xinshi"),
            (1592, 1127, "南市区", "Nanshi"),
            (1593, 1127, "北市区", "Beishi"),
            (1594, 1127, "涿州市", "Zhuozhou"),
            (1595, 1127, "定州市", "Dingzhou"),
            (1596, 1127, "安国市", "Anguo"),
            (1597, 1127, "高碑店市", "Gaobeidian"),
            (1598, 1127, "满城县", "Mancheng"),
            (1599, 1127, "清苑县", "Qingyuan"),
            (1600, 1127, "涞水县", "Laishui"),
            (1601, 1127, "阜平县", "Fuping"),
            (1602, 1127, "徐水县", "Xushui"),
            (1603, 1127, "定兴县", "Dingxing"),
            (1604, 1127, "唐县", "Tangxian"),
            (1605, 1127, "高阳县", "Gaoyang"),
            (1606, 1127, "容城县", "Rongcheng"),
            (1607, 1127, "涞源县", "Laiyuan"),
            (1608, 1127, "望都县", "Wangdu"),
            (1609, 1127, "安新县", "Anxin"),
            (1610, 1127, "易县", "Yixian"),
            (1611, 1127, "曲阳县", "Quyang"),
            (1612, 1127, "蠡县", "Lixian"),
            (1613, 1127, "顺平县", "Shunping"),
            (1614, 1127, "博野县", "Boye"),
            (1615, 1127, "雄县", "Xiongxian"),
            (1616, 1126, "桥西区", "Qiaoxi"),
            (1617, 1126, "桥东区", "Qiaodong"),
            (1618, 1126, "宣化区", "Xuanhua"),
            (1619, 1126, "下花园区", "Xiahuayuan"),
            (1620, 1126, "宣化县", "Xuanhua"),
            (1621, 1126, "阳原县", "Yangyuan"),
            (1622, 1126, "赤城县", "Chicheng"),
            (1623, 1126, "沽源县", "Guyuan"),
            (1624, 1126, "怀安县", "Huaian"),
            (1625, 1126, "怀来县", "Huailai"),
            (1626, 1126, "崇礼县", "Chongli"),
            (1627, 1126, "尚义县", "Shangyi"),
            (1628, 1126, "蔚县", "Weixian"),
            (1629, 1126, "涿鹿县", "Zhuolu"),
            (1630, 1126, "万全县", "Wanquan"),
            (1631, 1126, "康保县", "Kangbao"),
            (1632, 1126, "张北县", "Zhangbei"),
            (1633, 1129, "双桥区", "Shuangqiao"),
            (1634, 1129, "双滦区", "Shuangluan"),
            (1635, 1129, "鹰手营子矿区", "Yingshouyingzi"),
            (1636, 1129, "承德县", "Chengde"),
            (1637, 1129, "兴隆县", "Xinglong"),
            (1638, 1129, "隆化县", "Longhua"),
            (1639, 1129, "平泉县", "Pingquan"),
            (1640, 1129, "滦平县", "Luanping"),
            (1641, 1129, "丰宁满族自治县", "Fengning"),
            (1642, 1129, "围场满族蒙古族自治县", "Weichang"),
            (1643, 1129, "宽城满族自治县", "Kuancheng"),
            (1644, 1128, "运河区", "Yunhe"),
            (1645, 1128, "新华区", "Xinhua"),
            (1646, 1128, "泊头市", "Botou"),
            (1647, 1128, "任丘市", "Renqiu"),
            (1648, 1128, "黄骅市", "Huanghua"),
            (1649, 1128, "河间市", "Hejian"),
            (1650, 1128, "沧县", "Cangxian"),
            (1651, 1128, "青县", "Qingxian"),
            (1652, 1128, "献县", "Xianxian"),
            (1653, 1128, "东光县", "Dongguang"),
            (1654, 1128, "海兴县", "Haixing"),
            (1655, 1128, "盐山县", "Yanshan"),
            (1656, 1128, "肃宁县", "Suning"),
            (1657, 1128, "南皮县", "Nanpi"),
            (1658, 1128, "吴桥县", "Wuqiao"),
            (1659, 1128, "孟村回族自治县", "Mengcun"),
            (1660, 1121, "安次区", "Anci"),
            (1661, 1121, "广阳区", "Guangyang"),
            (1662, 1121, "霸州市", "Bazhou"),
            (1663, 1121, "三河市", "Sanhe"),
            (1664, 1121, "固安县", "Guan"),
            (1665, 1121, "永清县", "Yongqing"),
            (1666, 1121, "香河县", "Xianghe"),
            (1667, 1121, "大城县", "Dacheng"),
            (1668, 1121, "文安县", "Wenan"),
            (1669, 1121, "大厂回族自治县", "Daguang"),
            (1670, 1130, "桃城区", "Taocheng"),
            (1671, 1130, "冀州市", "Jizhou"),
            (1672, 1130, "深州市", "Shenzhou"),
            (1673, 1130, "饶阳县", "Raoyang"),
            (1674, 1130, "枣强县", "Zaoqiang"),
            (1675, 1130, "故城县", "Gucheng"),
            (1676, 1130, "阜城县", "Fucheng"),
            (1677, 1130, "安平县", "Anping"),
            (1678, 1130, "武邑县", "Wuyi"),
            (1679, 1130, "景县", "Jingxian"),
            (1680, 1130, "武强县", "Wuqiang"),
            (1681, 1281, "杏花岭区", "Xinhualing"),
            (1682, 1281, "小店区", "Xiaodian"),
            (1683, 1281, "迎泽区", "Yingze"),
            (1684, 1281, "尖草坪区", "Jiancaoping"),
            (1685, 1281, "万柏林区", "Wanbailin"),
            (1686, 1281, "晋源区", "Jinyuan"),
            (1687, 1281, "古交市", "Gujiao"),
            (1688, 1281, "阳曲县", "Yangqu"),
            (1689, 1281, "清徐县", "Qingxu"),
            (1690, 1281, "娄烦县", "Loufan"),
            (1691, 1285, "城区", "Urban Area"),
            (1692, 1285, "矿区", "Mining Area"),
            (1693, 1285, "南郊区", "Nanjiao"),
            (1694, 1285, "新荣区", "Xinrong"),
            (1695, 1285, "大同县", "Datong"),
            (1696, 1285, "天镇县", "Tianzhen"),
            (1697, 1285, "灵丘县", "Lingqiu"),
            (1698, 1285, "阳高县", "Yanggao"),
            (1699, 1285, "左云县", "Zuoyun"),
            (1700, 1285, "广灵县", "Guangling"),
            (1701, 1285, "浑源县", "Hunyuan"),
            (1702, 1282, "城区", "Urban Area"),
            (1703, 1282, "矿区", "Mining Area"),
            (1704, 1282, "郊区", "Suburb"),
            (1705, 1282, "平定县", "Pingding"),
            (1706, 1282, "盂县", "Yuxian"),
            (1707, 1284, "城区", "Urban Area"),
            (1708, 1284, "郊区", "Suburb"),
            (1709, 1284, "潞城市", "Lucheng"),
            (1710, 1284, "长治县", "Changzhi"),
            (1711, 1284, "长子县", "Zhangzi"),
            (1712, 1284, "平顺县", "Pingshun"),
            (1713, 1284, "襄垣县", "Xiangyuan"),
            (1714, 1284, "沁源县", "Qinyuan"),
            (1715, 1284, "屯留县", "Tunliu"),
            (1716, 1284, "黎城县", "Licheng"),
            (1717, 1284, "武乡县", "Wuxiang"),
            (1718, 1284, "沁县", "Qinxian"),
            (1719, 1284, "壶关县", "Huguan"),
            (1720, 1287, "城区", "Urban Area"),
            (1721, 1287, "高平市", "Gaoping"),
            (1722, 1287, "泽州县", "Zezhou"),
            (1723, 1287, "陵川县", "Lingchuan"),
            (1724, 1287, "阳城县", "Yangcheng"),
            (1725, 1287, "沁水县", "Qinshui"),
            (1726, 1280, "朔城区", "Shuocheng"),
            (1727, 1280, "平鲁区", "Pinglu"),
            (1728, 1280, "山阴县", "Shanyin"),
            (1729, 1280, "右玉县", "Youyu"),
            (1730, 1280, "应县", "Yingxian"),
            (1731, 1280, "怀仁县", "Huairen"),
            (1732, 1286, "榆次区", "Yuci"),
            (1733, 1286, "介休市", "Jiexiu"),
            (1734, 1286, "昔阳县", "Xiyang"),
            (1735, 1286, "灵石县", "Lingshi"),
            (1736, 1286, "祁县", "Qixian"),
            (1737, 1286, "左权县", "Zuoquan"),
            (1738, 1286, "寿阳县", "Shouyang"),
            (1739, 1286, "太谷县", "Taigu"),
            (1740, 1286, "和顺县", "Heshun"),
            (1741, 1286, "平遥县", "Pingyao"),
            (1742, 1286, "榆社县", "Yushe"),
            (1743, 1279, "忻府区", "Xinfu"),
            (1744, 1279, "原平市", "Yuanping"),
            (1745, 1279, "代县", "Daixian"),
            (1746, 1279, "神池县", "Shenchi"),
            (1747, 1279, "五寨县", "Wuzhai"),
            (1748, 1279, "五台县", "Wutai"),
            (1749, 1279, "偏关县", "Pianguan"),
            (1750, 1279, "宁武县", "Ningwu"),
            (1751, 1279, "静乐县", "Jingle"),
            (1752, 1279, "繁峙县", "Fanshi"),
            (1753, 1279, "河曲县", "Hequ"),
            (1754, 1279, "保德县", "Baode"),
            (1755, 1279, "定襄县", "Dingxiang"),
            (1756, 1279, "岢岚县", "Kelan"),
            (1757, 1278, "尧都区", "Yaodu"),
            (1758, 1278, "侯马市", "Houma"),
            (1759, 1278, "霍州市", "Huozhou"),
            (1760, 1278, "汾西县", "Fenxi"),
            (1761, 1278, "吉县", "Jixian"),
            (1762, 1278, "安泽县", "Anze"),
            (1763, 1278, "大宁县", "Daning"),
            (1764, 1278, "浮山县", "Fushan"),
            (1765, 1278, "古县", "Guxian"),
            (1766, 1278, "隰县", "Xixian"),
            (1767, 1278, "襄汾县", "Xiangfen"),
            (1768, 1278, "翼城县", "Yicheng"),
            (1769, 1278, "永和县", "Yonghe"),
            (1770, 1278, "乡宁县", "Xiangning"),
            (1771, 1278, "曲沃县", "Quwo"),
            (1772, 1278, "洪洞县", "Hongdong"),
            (1773, 1278, "蒲县", "Puxian"),
            (1774, 1283, "盐湖区", "Yanhu"),
            (1775, 1283, "河津市", "Hejin"),
            (1776, 1283, "永济市", "Yongji"),
            (1777, 1283, "闻喜县", "Wenxi"),
            (1778, 1283, "新绛县", "Xinjiang"),
            (1779, 1283, "平陆县", "Pinglu"),
            (1780, 1283, "垣曲县", "Yuanqu"),
            (1781, 1283, "绛县", "Jiangxian"),
            (1782, 1283, "稷山县", "Jishan"),
            (1783, 1283, "芮城县", "Ruicheng"),
            (1784, 1283, "夏县", "Xiaxian"),
            (1785, 1283, "万荣县", "Wanrong"),
            (1786, 1283, "临猗县", "Linyi"),
            (1787, 1277, "离石区", "Lishi"),
            (1788, 1277, "孝义市", "Xiaoyi"),
            (1789, 1277, "汾阳市", "Fenyang"),
            (1790, 1277, "文水县", "Wenshui"),
            (1791, 1277, "中阳县", "Zhongyang"),
            (1792, 1277, "兴县", "Xingxian"),
            (1793, 1277, "临县", "Linxian"),
            (1794, 1277, "方山县", "Fangshan"),
            (1795, 1277, "柳林县", "Liulin"),
            (1796, 1277, "岚县", "Lanxian"),
            (1797, 1277, "交口县", "Jiaokou"),
            (1798, 1277, "交城县", "Jiaocheng"),
            (1799, 1277, "石楼县", "Shilou"),
            (1800, 1223, "沈河区", "Shenhe"),
            (1801, 1223, "皇姑区", "Huanggu"),
            (1802, 1223, "和平区", "Heping"),
            (1803, 1223, "大东区", "Dadong"),
            (1804, 1223, "铁西区", "Tiexi"),
            (1805, 1223, "苏家屯区", "Sujiatun"),
            (1806, 1223, "东陵区", "Dongling"),
            (1807, 1223, "新城子区", "Xianchengzi"),
            (1808, 1223, "于洪区", "Yuhong"),
            (1809, 1223, "新民市", "Xinmin"),
            (1810, 1223, "法库县", "Faku"),
            (1811, 1223, "辽中县", "Liaozhong"),
            (1812, 1223, "康平县", "Kangpping"),
            (1813, 1230, "西岗区", "Xigang"),
            (1814, 1230, "中山区", "Zhongshan"),
            (1815, 1230, "沙河口区", "Shahekou"),
            (1816, 1230, "甘井子区", "Ganjingzi"),
            (1817, 1230, "旅顺口区", "Lvshunkou"),
            (1818, 1230, "金州区", "Jinzhou"),
            (1819, 1230, "瓦房店市", "Wafangdian"),
            (1820, 1230, "普兰店市", "Pulandian"),
            (1821, 1230, "庄河市", "Zhuanghe"),
            (1822, 1230, "长海县", "Changhai"),
            (1823, 1227, "铁东区", "Tiedong"),
            (1824, 1227, "铁西区", "Tiexi"),
            (1825, 1227, "立山区", "Lishan"),
            (1826, 1227, "千山区", "Qianshan"),
            (1827, 1227, "海城市", "Haicheng"),
            (1828, 1227, "台安县", "Taian"),
            (1829, 1227, "岫岩满族自治县", "Xiuyan"),
            (1830, 1232, "新抚区", "Xinfu"),
            (1831, 1232, "东洲区", "Dongzhou"),
            (1832, 1232, "望花区", "Wanghua"),
            (1833, 1232, "顺城区", "Shuncheng"),
            (1834, 1232, "抚顺县", "Fushun"),
            (1835, 1232, "清原满族自治县", "Qingyuan"),
            (1836, 1232, "新宾满族自治县", "Xinbin"),
            (1837, 1228, "平山区", "Pingshan"),
            (1838, 1228, "明山区", "Mingshan"),
            (1839, 1228, "溪湖区", "Xihu"),
            (1840, 1228, "南芬区", "Nanfen"),
            (1841, 1228, "本溪满族自治县", "Benxi"),
            (1842, 1228, "桓仁满族自治县", "Huanren"),
            (1843, 1231, "振兴区", "Zhenxing"),
            (1844, 1231, "元宝区", "Yuanbao"),
            (1845, 1231, "振安区", "Zhenan"),
            (1846, 1231, "东港市", "Donggang"),
            (1847, 1231, "凤城市", "Fengcheng"),
            (1848, 1231, "宽甸满族自治县", "Kuandian"),
            (1849, 1235, "太和区", "Taihe"),
            (1850, 1235, "古塔区", "Kuta"),
            (1851, 1235, "凌河区", "Linghe"),
            (1852, 1235, "凌海市", "Linghai"),
            (1853, 1235, "北宁市", "Beining"),
            (1854, 1235, "黑山县", "Heishan"),
            (1855, 1235, "义县", "Yixian"),
            (1856, 1234, "龙港区", "Longgang"),
            (1857, 1234, "南票区", "Nanpiao"),
            (1858, 1234, "连山区", "Lianshan"),
            (1859, 1234, "兴城市", "Xingcheng"),
            (1860, 1234, "绥中县", "Suizhong"),
            (1861, 1234, "建昌县", "Jianchang"),
            (1862, 1225, "站前区", "Zhanqian"),
            (1863, 1225, "西市区", "Xishi"),
            (1864, 1225, "鲅鱼圈区", "Bayuquan"),
            (1865, 1225, "老边区", "Laobian"),
            (1866, 1225, "大石桥市", "Dashiqiao"),
            (1867, 1225, "盖州市", "Gaizhou"),
            (1868, 1226, "双台子区", "Shuangtaizi"),
            (1869, 1226, "兴隆台区", "Xinglongtai"),
            (1870, 1226, "盘山县", "Panshan"),
            (1871, 1226, "大洼县", "Dawa"),
            (1872, 1233, "海州区", "Haizhou"),
            (1873, 1233, "新邱区", "Xinqiu"),
            (1874, 1233, "太平区", "Taiping"),
            (1875, 1233, "清河门区", "Qinghemen"),
            (1876, 1233, "细河区", "Xihe"),
            (1877, 1233, "彰武县", "Zhangwu"),
            (1878, 1233, "阜新蒙古族自治县", "Fuxin"),
            (1879, 1222, "白塔区", "Baita"),
            (1880, 1222, "文圣区", "Wensheng"),
            (1881, 1222, "宏伟区", "Hongwei"),
            (1882, 1222, "太子河区", "Taizihe"),
            (1883, 1222, "弓长岭区", "Gongchangling"),
            (1884, 1222, "灯塔市", "Dengta"),
            (1885, 1222, "辽阳县", "Liaoyang"),
            (1886, 1224, "银州区", "Yinzhou"),
            (1887, 1224, "清河区", "Qinghe"),
            (1888, 1224, "调兵山市", "Diaobingshan"),
            (1889, 1224, "开原市", "Kaiyuan"),
            (1890, 1224, "铁岭县", "Tieling"),
            (1891, 1224, "昌图县", "Changtu"),
            (1892, 1224, "西丰县", "Xifeng"),
            (1893, 1229, "双塔区", "Shuangta"),
            (1894, 1229, "龙城区", "Longcheng"),
            (1895, 1229, "凌源市", "Lingyuan"),
            (1896, 1229, "北票市", "Beipiao"),
            (1897, 1229, "朝阳县", "Chaoyang"),
            (1898, 1229, "建平县", "Jianping"),
            (1899, 1229, "喀喇沁左翼蒙古族自治县", "Kalaqin"),
            (1900, 1196, "朝阳区", "Chaoyang"),
            (1901, 1196, "宽城区", "Kuancheng"),
            (1902, 1196, "二道区", "Erdao"),
            (1903, 1196, "南关区", "Nanguan"),
            (1904, 1196, "绿圆区", "Lvyuan"),
            (1905, 1196, "双阳区", "Shuangyang"),
            (1906, 1196, "九台市", "Jiutai"),
            (1907, 1196, "榆树市", "Yushu"),
            (1908, 1196, "德惠市", "Dehui"),
            (1909, 1196, "农安县", "Nongan"),
            (1910, 1197, "船营区", "Chuanying"),
            (1911, 1197, "昌邑区", "Changyi"),
            (1912, 1197, "龙潭区", "Longtan"),
            (1913, 1197, "丰满区", "Fengman"),
            (1914, 1197, "舒兰市", "Shulan"),
            (1915, 1197, "桦甸市", "Huadian"),
            (1916, 1197, "蛟河市", "Jiaohe"),
            (1917, 1197, "磐石市", "Panshi"),
            (1918, 1197, "永吉县", "Yongji"),
            (1919, 1191, "铁西区", "Tiexi"),
            (1920, 1191, "铁东区", "Tiedong"),
            (1921, 1191, "公主岭市", "Gongzhuling"),
            (1922, 1191, "双辽市", "Shuangliao"),
            (1923, 1191, "梨树县", "Lishu"),
            (1924, 1191, "伊通满族自治县", "Yitong"),
            (1925, 1189, "龙山区", "Longshan"),
            (1926, 1189, "西安区", "Xian"),
            (1927, 1189, "东辽县", "Dongliao"),
            (1928, 1189, "东丰县", "Dongfeng"),
            (1929, 1192, "东昌区", "Dongchang"),
            (1930, 1192, "二道江区", "Erdaojiang"),
            (1931, 1192, "梅河口市", "Meihekou"),
            (1932, 1192, "集安市", "Jian"),
            (1933, 1192, "通化县", "Tonghua"),
            (1934, 1192, "辉南县", "Huinan"),
            (1935, 1192, "柳河县", "Liuhe"),
            (1936, 1194, "八道江区", "Badaojiang"),
            (1937, 1194, "临江市", "Linjiang"),
            (1938, 1194, "靖宇县", "Jingyu"),
            (1939, 1194, "抚松县", "Fusong"),
            (1940, 1194, "江源县", "Songyuan"),
            (1941, 1194, "长白朝鲜族自治县", "Changbai"),
            (1942, 1190, "宁江区", "Ningjiang"),
            (1943, 1190, "乾安县", "Qianan"),
            (1944, 1190, "长岭县", "Changling"),
            (1945, 1190, "扶余县", "Fuyu"),
            (1946, 1190, "前郭尔罗斯蒙古族自治县", "Qianguoerluosi"),
            (1947, 1195, "洮北区", "Taobei"),
            (1948, 1195, "大安市", "Daan"),
            (1949, 1195, "洮南市", "Taonan"),
            (1950, 1195, "镇赉县", "Zhenlai"),
            (1951, 1195, "通榆县", "Tongyu"),
            (1952, 1193, "延吉市", "Yanji"),
            (1953, 1193, "图们市", "Tumen"),
            (1954, 1193, "敦化市", "Dunhua"),
            (1955, 1193, "龙井市", "Longjing"),
            (1956, 1193, "珲春市", "Hunchun"),
            (1957, 1193, "和龙市", "Helong"),
            (1958, 1193, "安图县", "Antu"),
            (1959, 1193, "汪清县", "Wangqing"),
            (1960, 1157, "道里区", "Daoli"),
            (1961, 1157, "南岗区", "Nangang"),
            (1962, 1157, "动力区", "Dongli"),
            (1963, 1157, "平房区", "Pingfang"),
            (1964, 1157, "香坊区", "Xiangfang"),
            (1965, 1157, "松北区", "Songbei"),
            (1966, 1157, "呼兰区", "Hulan"),
            (1967, 1157, "道外区", "Daowai"),
            (1968, 1157, "阿城市", "Acheng"),
            (1969, 1157, "尚志市", "Shangzhi"),
            (1970, 1157, "双城市", "Shuangcheng"),
            (1971, 1157, "五常市", "Wuchang"),
            (1972, 1157, "方正县", "Fangzheng"),
            (1973, 1157, "宾县", "Binxian"),
            (1974, 1157, "依兰县", "Yilan"),
            (1975, 1157, "巴彦县", "Bayan"),
            (1976, 1157, "通河县", "Tonghe"),
            (1977, 1157, "木兰县", "Mulan"),
            (1978, 1157, "延寿县", "Yanshou"),
            (1979, 1152, "龙沙区", "Longsha"),
            (1980, 1152, "昂昂溪区", "Angangxi"),
            (1981, 1152, "铁峰区", "Tiefeng"),
            (1982, 1152, "建华区", "Jianhua"),
            (1983, 1152, "富拉尔基区", "Fulaerji"),
            (1984, 1152, "碾子山区", "Nianzishan"),
            (1985, 1152, "梅里斯达斡尔区", "Meilisidawoer"),
            (1986, 1152, "讷河市", "Nehe"),
            (1987, 1152, "富裕县", "Fuyu"),
            (1988, 1152, "拜泉县", "Baiquan"),
            (1989, 1152, "甘南县", "Gannan"),
            (1990, 1152, "依安县", "Yian"),
            (1991, 1152, "克山县", "Keshan"),
            (1992, 1152, "泰来县", "Tailai"),
            (1993, 1152, "克东县", "Kedong"),
            (1994, 1152, "龙江县", "Longjiang"),
            (1995, 1159, "兴山区", "Xingshan"),
            (1996, 1159, "工农区", "Gongnong"),
            (1997, 1159, "南山区", "Nanshan"),
            (1998, 1159, "兴安区", "Xingan"),
            (1999, 1159, "向阳区", "Xiangyang"),
            (2000, 1159, "东山区", "Dongshan"),
            (2001, 1159, "萝北县", "Luobei"),
            (2002, 1159, "绥滨县", "Suibin"),
            (2003, 1150, "尖山区", "Jianshan"),
            (2004, 1150, "岭东区", "Lingdong"),
            (2005, 1150, "四方台区", "Sifangtai"),
            (2006, 1150, "宝山区", "Baoshan"),
            (2007, 1150, "集贤县", "Jixian"),
            (2008, 1150, "宝清县", "Baoqing"),
            (2009, 1150, "友谊县", "Youyi"),
            (2010, 1150, "饶河县", "Raohe"),
            (2011, 1161, "鸡冠区", "Jiguan"),
            (2012, 1161, "恒山区", "Hengshan"),
            (2013, 1161, "城子河区", "Chengzihe"),
            (2014, 1161, "滴道区", "Didao"),
            (2015, 1161, "梨树区", "Lishu"),
            (2016, 1161, "麻山区", "Mashan"),
            (2017, 1161, "密山市", "Mishan"),
            (2018, 1161, "虎林市", "Hulin"),
            (2019, 1161, "鸡东县", "Jidong"),
            (2020, 1155, "萨尔图区", "Saertu"),
            (2021, 1155, "红岗区", "Honggang"),
            (2022, 1155, "龙凤区", "Longfeng"),
            (2023, 1155, "让胡路区", "Ranghulu"),
            (2024, 1155, "大同区", "Datong"),
            (2025, 1155, "林甸县", "Lindian"),
            (2026, 1155, "肇州县", "Zhaozhou"),
            (2027, 1155, "肇源县", "Zhaoyuan"),
            (2028, 1155, "杜尔伯特蒙古族自治县", "Duerbote"),
            (2029, 1151, "伊春区", "Yichun"),
            (2030, 1151, "带岭区", "Dailing"),
            (2031, 1151, "南岔区", "Nancha"),
            (2032, 1151, "金山屯区", "Jinshantun"),
            (2033, 1151, "西林区", "Xilin"),
            (2034, 1151, "美溪区", "Meixi"),
            (2035, 1151, "乌马河区", "Wumahe"),
            (2036, 1151, "翠峦区", "Cuiluan"),
            (2037, 1151, "友好区", "Youhao"),
            (2038, 1151, "上甘岭区", "Shanganling"),
            (2039, 1151, "五营区", "Wuying"),
            (2040, 1151, "红星区", "Hongxing"),
            (2041, 1151, "新青区", "Xinqing"),
            (2042, 1151, "汤旺河区", "Tangwanghe"),
            (2043, 1151, "乌伊岭区", "Wuyiling"),
            (2044, 1151, "铁力市", "Tieli"),
            (2045, 1151, "嘉荫县", "Jiayin"),
            (2046, 1153, "爱民区", "Aimin"),
            (2047, 1153, "东安区", "Dongan"),
            (2048, 1153, "阳明区", "Yangming"),
            (2049, 1153, "西安区", "Xian"),
            (2050, 1153, "绥芬河市", "Suifenhe"),
            (2051, 1153, "宁安市", "Ningan"),
            (2052, 1153, "海林市", "Hailin"),
            (2053, 1153, "穆棱市", "Muleng"),
            (2054, 1153, "林口县", "Linkou"),
            (2055, 1153, "东宁县", "Dongning"),
            (2056, 1160, "前进区", "Qianjin"),
            (2057, 1160, "永红区", "Yonghong"),
            (2058, 1160, "向阳区", "Xiangyang"),
            (2059, 1160, "东风区", "Dongfeng"),
            (2060, 1160, "郊区", "Suburb"),
            (2061, 1160, "同江市", "Tongjiang"),
            (2062, 1160, "富锦市", "Fujin"),
            (2063, 1160, "桦川县", "Huachuan"),
            (2064, 1160, "抚远县", "Fuyuan"),
            (2065, 1160, "桦南县", "Huanan"),
            (2066, 1160, "汤原县", "Tangyuan"),
            (2067, 1154, "桃山区", "Taoshan"),
            (2068, 1154, "新兴区", "Xinxing"),
            (2069, 1154, "茄子河区", "Qiezihe"),
            (2070, 1154, "勃利县", "Boli"),
            (2071, 1158, "爱辉区", "Aihui"),
            (2072, 1158, "北安市", "Beian"),
            (2073, 1158, "五大连池市", "Wudalianchi"),
            (2074, 1158, "逊克县", "Xunke"),
            (2075, 1158, "嫩江县", "Nenjiang"),
            (2076, 1158, "孙吴县", "Sunwu"),
            (2077, 1149, "北林区", "Beilin"),
            (2078, 1149, "安达市", "Anda"),
            (2079, 1149, "肇东市", "Zhaodong"),
            (2080, 1149, "海伦市", "Hailun"),
            (2081, 1149, "绥棱县", "Suileng"),
            (2082, 1149, "兰西县", "Lanxi"),
            (2083, 1149, "明水县", "Mingshui"),
            (2084, 1149, "青冈县", "Qinggang"),
            (2085, 1149, "庆安县", "Qingan"),
            (2086, 1149, "望奎县", "Wangkui"),
            (2087, 1156, "呼玛县", "Huma"),
            (2088, 1156, "塔河县", "Tahe"),
            (2089, 1156, "漠河县", "Mohe"),
            (2090, 1247, "回民区", "Huimin"),
            (2091, 1247, "玉泉区", "Yuquan"),
            (2092, 1247, "新城区", "Xincheng"),
            (2093, 1247, "赛罕区", "Saihan"),
            (2094, 1247, "托克托县", "Tuoketuo"),
            (2095, 1247, "清水河县", "Qingshuihe"),
            (2096, 1247, "武川县", "Wuchuan"),
            (2097, 1247, "和林格尔县", "Helingeer"),
            (2098, 1247, "土默特左旗", "Tumotezuo"),
            (2099, 1242, "昆都仑区", "Kundulun"),
            (2100, 1242, "青山区", "Qingshan"),
            (2101, 1242, "东河区", "Donghe"),
            (2102, 1242, "九原区", "Jiuyuan"),
            (2103, 1242, "石拐区", "Shiguai"),
            (2104, 1242, "白云矿区", "Baiyun Mining Area"),
            (2105, 1242, "固阳县", "Guyang"),
            (2106, 1242, "土默特右旗", "Tumoteyou"),
            (2107, 1242, "达尔罕茂明安联合旗", "Daerhan"),
            (2108, 1238, "海勃湾区", "Haibowan"),
            (2109, 1238, "乌达区", "Wuda"),
            (2110, 1238, "海南区", "Hainan"),
            (2111, 1244, "红山区", "Hongshan"),
            (2112, 1244, "元宝山区", "Yuanbaoshan"),
            (2113, 1244, "松山区", "Songshan"),
            (2114, 1244, "宁城县", "Ningcheng"),
            (2115, 1244, "林西县", "Linxi"),
            (2116, 1244, "喀喇沁旗", "Kalaqin"),
            (2117, 1244, "巴林左旗", "Balinzuo"),
            (2118, 1244, "敖汉旗", "Aohan"),
            (2119, 1244, "阿鲁科尔沁旗", "Alukeerqin"),
            (2120, 1244, "翁牛特旗", "Wengniute"),
            (2121, 1244, "克什克腾旗", "Keshike"),
            (2122, 1244, "巴林右旗", "Balinyou"),
            (2123, 1240, "科尔沁区", "Keerqin"),
            (2124, 1240, "霍林郭勒市", "Huolinguole"),
            (2125, 1240, "开鲁县", "Kailu"),
            (2126, 1240, "科尔沁左翼中旗", "Keerqinzuoyizhong"),
            (2127, 1240, "科尔沁左翼后旗", "Keerqinzuoyihou"),
            (2128, 1240, "库伦旗", "Kulun"),
            (2129, 1240, "奈曼旗", "Naiman"),
            (2130, 1240, "扎鲁特旗", "Zhalute"),
            (2131, 1245, "东胜区", "Dongsheng"),
            (2132, 1245, "准格尔旗", "Zhunger"),
            (2133, 1245, "乌审旗", "Wushen"),
            (2134, 1245, "伊金霍洛旗", "Yijinhuoluo"),
            (2135, 1245, "鄂托克旗", "Etuoke"),
            (2136, 1245, "鄂托克前旗", "Etuokeqian"),
            (2137, 1245, "杭锦旗", "Hangjin"),
            (2138, 1245, "达拉特旗", "Dalate"),
            (2139, 1246, "海拉尔区", "Hailaer"),
            (2140, 1246, "满洲里市", "Manzhouli"),
            (2141, 1246, "牙克石市", "Yakeshi"),
            (2142, 1246, "扎兰屯市", "Zhalantun"),
            (2143, 1246, "根河市", "Genhe"),
            (2144, 1246, "额尔古纳市", "Eerguna"),
            (2145, 1246, "陈巴尔虎旗", "Chenbaerhuqi"),
            (2146, 1246, "阿荣旗", "Arong"),
            (2147, 1246, "新巴尔虎左旗", "Xinbaerhuzuo"),
            (2148, 1246, "新巴尔虎右旗", "Xinbaerhuyou"),
            (2149, 1246, "鄂伦春自治旗", "Elunchun"),
            (2150, 1246, "莫力达瓦达斡尔族自治旗", "Molidawadawoer"),
            (2151, 1246, "鄂温克族自治旗", "Ewenke"),
            (2152, 1237, "丰镇市", "Fengzhen"),
            (2153, 1237, "集宁区", "Jining"),
            (2154, 1237, "兴和县", "Xinghe"),
            (2155, 1237, "卓资县", "Zhuozi"),
            (2156, 1237, "商都县", "Shangdu"),
            (2157, 1237, "凉城县", "Liangcheng"),
            (2158, 1237, "化德县", "Huade"),
            (2159, 1237, "察哈尔右翼前旗", "Chahaeryouyiqian"),
            (2160, 1237, "察哈尔右翼中旗", "Chahaeryouyizhong"),
            (2161, 1237, "察哈尔右翼后旗", "Chahaeryouyihou"),
            (2162, 1237, "四子王旗", "Siziwang"),
            (2163, 1239, "锡林浩特市", "Xilinhaote"),
            (2164, 1239, "二连浩特市", "Erlianhaote"),
            (2165, 1239, "多伦县", "Duolun"),
            (2166, 1239, "阿巴嘎旗", "Abaga"),
            (2167, 1239, "西乌珠穆沁旗", "Xiwuzhumuqin"),
            (2168, 1239, "东乌珠穆沁旗", "Dongwuzhumuqin"),
            (2169, 1239, "苏尼特左旗", "Sunitezuo"),
            (2170, 1239, "苏尼特右旗", "Suniteyou"),
            (2171, 1239, "太仆寺旗", "Taipusi"),
            (2172, 1239, "正镶白旗", "Zhengxiangbai"),
            (2173, 1239, "正蓝旗", "Zhenglan"),
            (2174, 1239, "镶黄旗", "Xianghuang"),
            (2175, 1241, "临河区", "Linhe"),
            (2176, 1241, "五原县", "Wuyuan"),
            (2177, 1241, "磴口县", "Dengkou"),
            (2178, 1241, "杭锦后旗", "Hangjinhou"),
            (2179, 1241, "乌拉特中旗", "Wulatezhong"),
            (2180, 1241, "乌拉特前旗", "Wulateqian"),
            (2181, 1241, "乌拉特后旗", "Wulatehou"),
            (2182, 1243, "阿拉善左旗", "Alashanzuo"),
            (2183, 1243, "阿拉善右旗", "Alashanyou"),
            (2184, 1243, "额济纳旗", "Ejina"),
            (2185, 1236, "乌兰浩特市", "Wulanhaote"),
            (2186, 1236, "阿尔山市", "Aershan"),
            (2187, 1236, "突泉县", "Tuquan"),
            (2188, 1236, "扎赉特旗", "Zhalaite"),
            (2189, 1236, "科尔沁右翼前旗", "Keerqinyouyiqian"),
            (2190, 1236, "科尔沁右翼中旗", "Keerqinyouyizhong"),
            (2191, 1208, "玄武区", "Xuanwu"),
            (2192, 1208, "鼓楼区", "Gulou"),
            (2193, 1208, "建邺区", "Jianye"),
            (2194, 1208, "白下区", "Baixia"),
            (2195, 1208, "秦淮区", "Qinhuai"),
            (2196, 1208, "下关区", "Xiaguan"),
            (2197, 1208, "雨花台区", "Yuhuatai"),
            (2198, 1208, "浦口区", "Pukou"),
            (2199, 1208, "栖霞区", "Qixia"),
            (2200, 1208, "大厂区", "Dachang"),
            (2201, 1208, "江宁区", "Jiangning"),
            (2202, 1208, "溧水县", "Lishui"),
            (2203, 1208, "高淳县", "Gaochun"),
            (2204, 1208, "六合县", "Liuhe"),
            (2205, 1208, "江浦县", "Jiangpu"),
            (2206, 1199, "云龙区", "Yunlong"),
            (2207, 1199, "鼓楼区", "Gulou"),
            (2208, 1199, "九里区", "Jiuli"),
            (2209, 1199, "贾汪区", "Jiawang"),
            (2210, 1199, "贾汪区", "Jiawang"),
            (2211, 1199, "邳州市", "Pizhou"),
            (2212, 1199, "新沂市", "Xinyi"),
            (2213, 1199, "铜山县", "Tongshan"),
            (2214, 1199, "睢宁县", "Suining"),
            (2215, 1199, "沛县", "Peixian"),
            (2216, 1199, "丰县", "Fengxian"),
            (2217, 1198, "新浦区", "Xinpu"),
            (2218, 1198, "连云区", "Lianyun"),
            (2219, 1198, "海州区", "Haizhou"),
            (2220, 1198, "东海县", "Donghai"),
            (2221, 1198, "灌云县", "Guanyun"),
            (2222, 1198, "赣榆县", "Ganyu"),
            (2223, 1198, "灌南县", "Guannan"),
            (2224, 1210, "清河区", "Qinghe"),
            (2225, 1210, "清浦区", "Qingpu"),
            (2226, 1210, "楚州区", "Chuzhou"),
            (2227, 1210, "淮阴区", "Huaiyin"),
            (2228, 1210, "涟水县", "Lianshui"),
            (2229, 1210, "洪泽县", "Hongze"),
            (2230, 1210, "金湖县", "Jinhu"),
            (2231, 1210, "盱眙县", "Xuyi"),
            (2232, 1201, "宿城区", "Sucheng"),
            (2233, 1201, "宿豫县", "Suyu"),
            (2234, 1201, "沭阳县", "Shuyang"),
            (2235, 1201, "泗阳县", "Siyang"),
            (2236, 1201, "泗洪县", "Sihong"),
            (2237, 1205, "城区", "Urban Area"),
            (2238, 1205, "东台市", "Dongtai"),
            (2239, 1205, "大丰市", "Dafeng"),
            (2240, 1205, "盐都县", "Yandu"),
            (2241, 1205, "建湖县", "Jianhu"),
            (2242, 1205, "响水县", "Xiangshui"),
            (2243, 1205, "阜宁县", "Funing"),
            (2244, 1205, "射阳县", "Sheyang"),
            (2245, 1205, "滨海县", "Binhai"),
            (2246, 1204, "广陵区", "Guangling"),
            (2247, 1204, "维扬区", "Weiyang"),
            (2248, 1204, "邗江区", "Hanjiang"),
            (2249, 1204, "高邮市", "Gaoyou"),
            (2250, 1204, "江都市", "Jiangdu"),
            (2251, 1204, "仪征市", "Yizheng"),
            (2252, 1204, "宝应县", "Baoying"),
            (2253, 1202, "海陵区", "Hailing"),
            (2254, 1202, "高港区", "Gaogang"),
            (2255, 1202, "泰兴市", "Taixing"),
            (2256, 1202, "姜堰市", "Jiangyan"),
            (2257, 1202, "靖江市", "Jingjiang"),
            (2258, 1202, "兴化市", "Xinghua"),
            (2259, 1207, "崇川区", "Chongchuan"),
            (2260, 1207, "港闸区", "Gangzha"),
            (2261, 1207, "如皋市", "Rugao"),
            (2262, 1207, "通州市", "Tongzhou"),
            (2263, 1207, "海门市", "Haimen"),
            (2264, 1207, "启东市", "Qidong"),
            (2265, 1207, "海安县", "Haian"),
            (2266, 1207, "如东县", "Rudong"),
            (2267, 1206, "京口区", "Jingkou"),
            (2268, 1206, "润州区", "Runzhou"),
            (2269, 1206, "丹阳市", "Danyang"),
            (2270, 1206, "扬中市", "Yangzhong"),
            (2271, 1206, "句容市", "Jurong"),
            (2272, 1206, "丹徒县", "Dantu"),
            (2273, 1209, "钟楼区", "Zhonglou"),
            (2274, 1209, "天宁区", "Tianning"),
            (2275, 1209, "戚墅堰区", "Qishuyan"),
            (2276, 1209, "郊区", "Suburb"),
            (2277, 1209, "金坛市", "Jintan"),
            (2278, 1209, "溧阳市", "Liyang"),
            (2279, 1209, "武进市", "Wujin"),
            (2280, 1203, "崇安区", "Chongan"),
            (2281, 1203, "北塘区", "Beitang"),
            (2282, 1203, "南长区", "Nanchang"),
            (2283, 1203, "锡山区", "Xishan"),
            (2284, 1203, "惠山区", "Huishan"),
            (2285, 1203, "滨湖区", "Binhu"),
            (2286, 1203, "江阴市", "Jiangyin"),
            (2287, 1203, "宜兴市", "Yixing"),
            (2288, 1200, "沧浪区", "Canglang"),
            (2289, 1200, "金阊区", "Jinchang"),
            (2290, 1200, "平江区", "Pingjiang"),
            (2291, 1200, "虎丘区", "Huqiu"),
            (2292, 1200, "吴中区", "Wuzhong"),
            (2293, 1200, "相城区", "Xiangcheng"),
            (2294, 1200, "常熟市", "Changshu"),
            (2295, 1200, "张家港市", "Zhangjiagang"),
            (2296, 1200, "太仓市", "Taicang"),
            (2297, 1200, "昆山市", "Kunshan"),
            (2298, 1200, "吴江市", "Wujiang"),
            (2299, 1361, "拱墅区", "Gongshu"),
            (2300, 1361, "西湖区", "Xihu"),
            (2301, 1361, "上城区", "Shangcheng"),
            (2302, 1361, "下城区", "Xiacheng"),
            (2303, 1361, "江干区", "Jianggan"),
            (2304, 1361, "滨江区", "Binjiang"),
            (2305, 1361, "余杭区", "Yuhang"),
            (2306, 1361, "萧山区", "Xiaoshan"),
            (2307, 1361, "建德市", "Jiande"),
            (2308, 1361, "富阳市", "Fuyang"),
            (2309, 1361, "临安市", "Linan"),
            (2310, 1361, "桐庐县", "Tonglu"),
            (2311, 1361, "淳安县", "Chunan"),
            (2312, 1359, "海曙区", "Haishu"),
            (2313, 1359, "江东区", "Jiangdong"),
            (2314, 1359, "江北区", "Jiangbei"),
            (2315, 1359, "镇海区", "Zhenhai"),
            (2316, 1359, "北仑区", "Beilun"),
            (2317, 1359, "鄞州区", "Yinzhou"),
            (2318, 1359, "余姚市", "Yuyao"),
            (2319, 1359, "慈溪市", "Cixi"),
            (2320, 1359, "奉化市", "Fenghua"),
            (2321, 1359, "宁海县", "Ninghai"),
            (2322, 1359, "象山县", "Xiangshan"),
            (2323, 1357, "鹿城区", "Lucheng"),
            (2324, 1357, "龙湾区", "Longwan"),
            (2325, 1357, "瓯海区", "Ouhai"),
            (2326, 1357, "瑞安市", "Ruian"),
            (2327, 1357, "乐清市", "Yueqing"),
            (2328, 1357, "永嘉县", "Yongjia"),
            (2329, 1357, "洞头县", "Dongtou"),
            (2330, 1357, "平阳县", "Pingyang"),
            (2331, 1357, "苍南县", "Cangnan"),
            (2332, 1357, "文成县", "Wencheng"),
            (2333, 1357, "泰顺县", "Taishun"),
            (2334, 1363, "秀城区", "Xiucheng"),
            (2335, 1363, "秀洲区", "Xiuzhou"),
            (2336, 1363, "海宁市", "Haining"),
            (2337, 1363, "平湖市", "Pinghu"),
            (2338, 1363, "桐乡市", "Tongxiang"),
            (2339, 1363, "嘉善县", "Jiashan"),
            (2340, 1363, "海盐县", "Haiyan"),
            (2341, 1362, "吴兴区", "Wuxing"),
            (2342, 1362, "南浔区", "Nanxun"),
            (2343, 1362, "长兴县", "Changxing"),
            (2344, 1362, "德清县", "Deqing"),
            (2345, 1362, "安吉县", "Anji"),
            (2346, 1356, "越城区", "Yuecheng"),
            (2347, 1356, "诸暨市", "Zhuji"),
            (2348, 1356, "上虞市", "Shangyu"),
            (2349, 1356, "嵊州市", "Shengzhou"),
            (2350, 1356, "绍兴县", "Shaoxing"),
            (2351, 1356, "新昌县", "Xinchang"),
            (2352, 1364, "婺城区", "Wucheng"),
            (2353, 1364, "金东区", "Jindong"),
            (2354, 1364, "兰溪市", "Lanxi"),
            (2355, 1364, "义乌市", "Yiwu"),
            (2356, 1364, "东阳市", "Dongyang"),
            (2357, 1364, "永康市", "Yongkang"),
            (2358, 1364, "武义县", "Wuyi"),
            (2359, 1364, "浦江县", "Pujiang"),
            (2360, 1364, "磐安县", "Panan"),
            (2361, 1354, "柯城区", "Kecheng"),
            (2362, 1354, "衢江区", "Qujiang"),
            (2363, 1354, "江山市", "Jiangshan"),
            (2364, 1354, "龙游县", "Longyou"),
            (2365, 1354, "常山县", "Changshan"),
            (2366, 1354, "开化县", "Kaihua"),
            (2367, 1360, "定海区", "Dinghai"),
            (2368, 1360, "普陀区", "Putuo"),
            (2369, 1360, "岱山县", "Daishan"),
            (2370, 1360, "嵊泗县", "Shengsi"),
            (2371, 1358, "椒江区", "Jiaojiang"),
            (2372, 1358, "黄岩区", "Huangyan"),
            (2373, 1358, "路桥区", "Luqiao"),
            (2374, 1358, "临海市", "Linhai"),
            (2375, 1358, "温岭市", "Wenling"),
            (2376, 1358, "玉环县", "Yuhuan"),
            (2377, 1358, "天台县", "Tiantai"),
            (2378, 1358, "仙居县", "Xianju"),
            (2379, 1358, "三门县", "Sanmen"),
            (2380, 1355, "莲都区", "Liandu"),
            (2381, 1355, "龙泉市", "Longquan"),
            (2382, 1355, "缙云县", "Jinyun"),
            (2383, 1355, "青田县", "Qingtian"),
            (2384, 1355, "云和县", "Yunhe"),
            (2385, 1355, "遂昌县", "Suichang"),
            (2386, 1355, "松阳县", "Songyang"),
            (2387, 1355, "庆元县", "Qingyuan"),
            (2388, 1355, "景宁畲族自治县", "Jingning"),
            (2389, 1047, "庐阳区", "Luyang"),
            (2390, 1047, "瑶海区", "Yaohai"),
            (2391, 1047, "蜀山区", "Shushan"),
            (2392, 1047, "包河区", "Baohe"),
            (2393, 1047, "长丰县", "Changfeng"),
            (2394, 1047, "肥东县", "Feidong"),
            (2395, 1047, "肥西县", "Feixi"),
            (2396, 1039, "镜湖区", "Jinghu"),
            (2397, 1039, "新芜区", "Xinwu"),
            (2398, 1039, "马塘区", "Matang"),
            (2399, 1039, "鸠江区", "Jiujiang"),
            (2400, 1039, "芜湖县", "Wuhu"),
            (2401, 1039, "南陵县", "Nanling"),
            (2402, 1039, "繁昌县", "Fanchang"),
            (2403, 1041, "中市区", "Zhongshi"),
            (2404, 1041, "东市区", "Dongshi"),
            (2405, 1041, "西市区", "Xishi"),
            (2406, 1041, "郊区", "Suburb"),
            (2407, 1041, "怀远县", "Huaiyuan"),
            (2408, 1041, "固镇县", "Guzhen"),
            (2409, 1041, "五河县", "Wuhe"),
            (2410, 1049, "田家庵区", "Tianjiaan"),
            (2411, 1049, "大通区", "Datong"),
            (2412, 1049, "谢家集区", "Xiejiaji"),
            (2413, 1049, "八公山区", "Bagongshan"),
            (2414, 1049, "潘集区", "Panji"),
            (2415, 1049, "凤台县", "Fengtai"),
            (2416, 1034, "雨山区", "Yushan"),
            (2417, 1034, "花山区", "Huashan"),
            (2418, 1034, "金家庄区", "Jinjiazhuang"),
            (2419, 1034, "当涂县", "Dangtu"),
            (2420, 1050, "相山区", "Xiangshan"),
            (2421, 1050, "杜集区", "Duji"),
            (2422, 1050, "烈山区", "Lieshan"),
            (2423, 1050, "濉溪县", "Suixi"),
            (2424, 1038, "铜官山区", "Tongguanshan"),
            (2425, 1038, "狮子山区", "Shizishan"),
            (2426, 1038, "郊区", "Suburb"),
            (2427, 1038, "铜陵县", "Tongling"),
            (2428, 1042, "迎江区", "Yingjiang"),
            (2429, 1042, "大观区", "Daguan"),
            (2430, 1042, "郊区", "Suburb"),
            (2431, 1042, "桐城市", "Tongcheng"),
            (2432, 1042, "宿松县", "Susong"),
            (2433, 1042, "枞阳县", "Zongyang"),
            (2434, 1042, "太湖县", "Taihu"),
            (2435, 1042, "怀宁县", "Huaining"),
            (2436, 1042, "岳西县", "Yuexi"),
            (2437, 1042, "望江县", "Wangjiang"),
            (2438, 1042, "潜山县", "Qianshan"),
            (2439, 1048, "屯溪区", "Tunxi"),
            (2440, 1048, "黄山区", "Huangshan"),
            (2441, 1048, "徽州区", "Huizhou"),
            (2442, 1048, "休宁县", "Xiuning"),
            (2443, 1048, "歙县", "Shexian"),
            (2444, 1048, "祁门县", "Qimen"),
            (2445, 1048, "黟县", "Yixian"),
            (2446, 1043, "琅琊区", "Langya"),
            (2447, 1043, "南谯区", "Nanqiao"),
            (2448, 1043, "天长市", "Tianchang"),
            (2449, 1043, "明光市", "Mingguang"),
            (2450, 1043, "全椒县", "Quanjiao"),
            (2451, 1043, "来安县", "Laian"),
            (2452, 1043, "定远县", "Dingyuan"),
            (2453, 1043, "凤阳县", "Fengyang"),
            (2454, 1045, "颖州区", "Yingzhou"),
            (2455, 1045, "颖东区", "Yingdong"),
            (2456, 1045, "颖泉区", "Yingquan"),
            (2457, 1045, "界首市", "Jieshou"),
            (2458, 1045, "临泉县", "Linquan"),
            (2459, 1045, "颖上县", "Yingshang"),
            (2460, 1045, "阜南县", "Funan"),
            (2461, 1045, "太和县", "Taihe"),
            (2462, 1037, "埇桥区", "Yongqiao"),
            (2463, 1037, "萧县", "Xianxian"),
            (2464, 1037, "泗县", "Sixian"),
            (2465, 1037, "砀山县", "Dangshan"),
            (2466, 1037, "灵璧县", "Lingbi"),
            (2467, 1044, "居巢区", "Juchao"),
            (2468, 1044, "含山县", "Hanshan"),
            (2469, 1044, "无为县", "Wuwei"),
            (2470, 1044, "庐江县", "Lujiang"),
            (2471, 1044, "和县", "Hexian"),
            (2472, 1035, "金安区", "Jinan"),
            (2473, 1035, "裕安区", "Yuan"),
            (2474, 1035, "寿县", "Shouxian"),
            (2475, 1035, "霍山县", "Huoshan"),
            (2476, 1035, "霍邱县", "Huoqiu"),
            (2477, 1035, "舒城县", "Shucheng"),
            (2478, 1035, "金寨县", "Jinzhai"),
            (2479, 1040, "谯城区", "Qiaocheng"),
            (2480, 1040, "利辛县", "Lixin"),
            (2481, 1040, "涡阳县", "Guoyang"),
            (2482, 1040, "蒙城县", "Mengcheng"),
            (2483, 1036, "宣州区", "Xuanzhou"),
            (2484, 1036, "宁国市", "Ningguo"),
            (2485, 1036, "广德县", "Guangde"),
            (2486, 1036, "郎溪县", "Langxi"),
            (2487, 1036, "泾县", "Jingxian"),
            (2488, 1036, "旌德县", "Jingde"),
            (2489, 1036, "绩溪县", "Jixi"),
            (2490, 1046, "贵池区", "Guichi"),
            (2491, 1046, "东至县", "Dongzhi"),
            (2492, 1046, "石台县", "Shitai"),
            (2493, 1046, "青阳县", "Qingyang"),
            (2494, 1059, "鼓楼区", "Gulou"),
            (2495, 1059, "台江区", "Taijiang"),
            (2496, 1059, "仓山区", "Cangshan"),
            (2497, 1059, "马尾区", "Mawei"),
            (2498, 1059, "晋安区", "Jinan"),
            (2499, 1059, "福清市", "Fuqing"),
            (2500, 1059, "长乐市", "Changle"),
            (2501, 1059, "闽侯县", "Minhou"),
            (2502, 1059, "闽清县", "Minqing"),
            (2503, 1059, "永泰县", "Yongtai"),
            (2504, 1059, "连江县", "Lianjiang"),
            (2505, 1059, "罗源县", "Luoyuan"),
            (2506, 1059, "平潭县", "Pingtan"),
            (2507, 1054, "集美区", "Jimei"),
            (2508, 1054, "海沧区", "Haicang"),
            (2509, 1054, "思明区", "Siming"),
            (2510, 1054, "湖里区", "Huli"),
            (2511, 1054, "同安区", "Tongan"),
            (2512, 1054, "翔安区", "Xiangan"),
            (2513, 1052, "梅列区", "Meilie"),
            (2514, 1052, "三元区", "Sanyuan"),
            (2515, 1052, "永安市", "Yongan"),
            (2516, 1052, "明溪县", "Mingxi"),
            (2517, 1052, "将乐县", "Jiangle"),
            (2518, 1052, "大田县", "Datian"),
            (2519, 1052, "宁化县", "Ninghua"),
            (2520, 1052, "建宁县", "Jianning"),
            (2521, 1052, "沙县", "Shaxian"),
            (2522, 1052, "尤溪县", "Youxi"),
            (2523, 1052, "清流县", "Qingliu"),
            (2524, 1052, "泰宁县", "Taining"),
            (2525, 1056, "城厢区", "Changxiang"),
            (2526, 1056, "涵江区", "Hanjiang"),
            (2527, 1056, "荔城区", "Licheng"),
            (2528, 1056, "秀屿区", "Xiuyu"),
            (2529, 1056, "仙游县", "Xianyou"),
            (2530, 1053, "鲤城区", "Licheng"),
            (2531, 1053, "丰泽区", "Fengze"),
            (2532, 1053, "洛江区", "Luojiang"),
            (2533, 1053, "泉港区", "Quangang"),
            (2534, 1053, "石狮市", "Shishi"),
            (2535, 1053, "晋江市", "Jinjiang"),
            (2536, 1053, "南安市", "Nanan"),
            (2537, 1053, "惠安县", "Huian"),
            (2538, 1053, "永春县", "Yongchun"),
            (2539, 1053, "安溪县", "Anxi"),
            (2540, 1053, "德化县", "Dehua"),
            (2541, 1053, "金门县", "Jinmen"),
            (2542, 1055, "芗城区", "Xiangcheng"),
            (2543, 1055, "龙文区", "Longwen"),
            (2544, 1055, "龙海市", "Longhai"),
            (2545, 1055, "平和县", "Pinghe"),
            (2546, 1055, "南靖县", "Nanjing"),
            (2547, 1055, "诏安县", "Zhaoan"),
            (2548, 1055, "漳浦县", "Zhangpu"),
            (2549, 1055, "华安县", "Huaan"),
            (2550, 1055, "东山县", "Dongshan"),
            (2551, 1055, "长泰县", "Changtai"),
            (2552, 1055, "云霄县", "Yunxiao"),
            (2553, 1057, "延平区", "Yanping"),
            (2554, 1057, "建瓯市", "Jianou"),
            (2555, 1057, "邵武市", "Shaowu"),
            (2556, 1057, "武夷山市", "Wuyishan"),
            (2557, 1057, "建阳市", "Jianyang"),
            (2558, 1057, "松溪县", "Songxi"),
            (2559, 1057, "光泽县", "Guangze"),
            (2560, 1057, "顺昌县", "Shunchang"),
            (2561, 1057, "浦城县", "Pucheng"),
            (2562, 1057, "政和县", "Zhenghe"),
            (2563, 1051, "新罗区", "Xinluo"),
            (2564, 1051, "漳平市", "Zhangping"),
            (2565, 1051, "长汀县", "Changting"),
            (2566, 1051, "武平县", "Wuping"),
            (2567, 1051, "上杭县", "Shanghang"),
            (2568, 1051, "永定县", "Yongding"),
            (2569, 1051, "连城县", "Liancheng"),
            (2570, 1058, "蕉城区", "Jiaocheng"),
            (2571, 1058, "福安市", "Fuan"),
            (2572, 1058, "福鼎市", "Fuding"),
            (2573, 1058, "寿宁县", "Shouning"),
            (2574, 1058, "霞浦县", "Xiapu"),
            (2575, 1058, "柘荣县", "Zherong"),
            (2576, 1058, "屏南县", "Pingnan"),
            (2577, 1058, "古田县", "Gutian"),
            (2578, 1058, "周宁县", "Zhouning"),
            (2579, 1215, "东湖区", "Donghu"),
            (2580, 1215, "西湖区", "Xihu"),
            (2581, 1215, "青云谱区", "Qingyun"),
            (2582, 1215, "湾里区", "Wanli"),
            (2583, 1215, "青山湖区", "Qingshanhu"),
            (2584, 1215, "新建县", "Xinjian"),
            (2585, 1215, "南昌县", "Nanchang"),
            (2586, 1215, "进贤县", "Jinxian"),
            (2587, 1215, "安义县", "Anyi"),
            (2588, 1221, "珠山区", "Zhushan"),
            (2589, 1221, "昌江区", "Changjiang"),
            (2590, 1221, "乐平市", "Leping"),
            (2591, 1221, "浮梁县", "Fuliang"),
            (2592, 1216, "安源区", "Anyuan"),
            (2593, 1216, "湘东区", "Xiangdong"),
            (2594, 1216, "莲花县", "Lianhua"),
            (2595, 1216, "上栗县", "Shangli"),
            (2596, 1216, "芦溪县", "Luxi"),
            (2597, 1211, "渝水区", "Yushui"),
            (2598, 1211, "分宜县", "Fenyi"),
            (2599, 1220, "浔阳区", "Xunyang"),
            (2600, 1220, "庐山区", "Lushan"),
            (2601, 1220, "瑞昌市", "Ruichang"),
            (2602, 1220, "九江县", "Jiujiang"),
            (2603, 1220, "星子县", "Xingzi"),
            (2604, 1220, "武宁县", "Wuning"),
            (2605, 1220, "彭泽县", "Pengze"),
            (2606, 1220, "永修县", "Yongxiu"),
            (2607, 1220, "修水县", "Xiushui"),
            (2608, 1220, "湖口县", "Hukou"),
            (2609, 1220, "德安县", "Dean"),
            (2610, 1220, "都昌县", "Duchang"),
            (2611, 1214, "月湖区", "Yuehu"),
            (2612, 1214, "贵溪市", "Guixi"),
            (2613, 1214, "余江县", "Yujiang"),
            (2614, 1217, "章贡区", "Zhanggong"),
            (2615, 1217, "瑞金市", "Ruijin"),
            (2616, 1217, "南康市", "Nankang"),
            (2617, 1217, "石城县", "Shicheng"),
            (2618, 1217, "安远县", "Anyuan"),
            (2619, 1217, "赣县", "Ganxian"),
            (2620, 1217, "宁都县", "Ningdu"),
            (2621, 1217, "寻乌县", "Xunwu"),
            (2622, 1217, "兴国县", "Xingguo"),
            (2623, 1217, "定南县", "Dingnan"),
            (2624, 1217, "上犹县", "Shangyou"),
            (2625, 1217, "于都县", "Yudu"),
            (2626, 1217, "龙南县", "Longnan"),
            (2627, 1217, "崇义县", "Chongyi"),
            (2628, 1217, "信丰县", "Xinfeng"),
            (2629, 1217, "全南县", "Quannan"),
            (2630, 1217, "大余县", "Dayu"),
            (2631, 1217, "会昌县", "Huichang"),
            (2632, 1219, "吉州区", "Jizhou"),
            (2633, 1219, "青原区", "Qingyuan"),
            (2634, 1219, "井冈山市", "Jinggangshan"),
            (2635, 1219, "吉安县", "Jian"),
            (2636, 1219, "永丰县", "Yongfeng"),
            (2637, 1219, "永新县", "Yongxin"),
            (2638, 1219, "新干县", "Xingan"),
            (2639, 1219, "泰和县", "Taihe"),
            (2640, 1219, "峡江县", "Xiajiang"),
            (2641, 1219, "遂川县", "Suichuan"),
            (2642, 1219, "安福县", "Anfu"),
            (2643, 1219, "吉水县", "Jishui"),
            (2644, 1219, "万安县", "Wanan"),
            (2645, 1213, "袁州区", "Yuanzhou"),
            (2646, 1213, "丰城市", "Fengcheng"),
            (2647, 1213, "樟树市", "Zhangshu"),
            (2648, 1213, "高安市", "Gaoan"),
            (2649, 1213, "铜鼓县", "Tonggu"),
            (2650, 1213, "靖安县", "Jingan"),
            (2651, 1213, "宜丰县", "Yifeng"),
            (2652, 1213, "奉新县", "Fengxin"),
            (2653, 1213, "万载县", "Waizai"),
            (2654, 1213, "上高县", "Shanggao"),
            (2655, 1218, "临川区", "Linchuan"),
            (2656, 1218, "南丰县", "Nanfeng"),
            (2657, 1218, "乐安县", "Lean"),
            (2658, 1218, "金溪县", "Jinxi"),
            (2659, 1218, "南城县", "Nancheng"),
            (2660, 1218, "东乡县", "Dongxiang"),
            (2661, 1218, "资溪县", "Zixi"),
            (2662, 1218, "宜黄县", "Yihuang"),
            (2663, 1218, "广昌县", "Guangchang"),
            (2664, 1218, "黎川县", "Lichuan"),
            (2665, 1218, "崇仁县", "Chongren"),
            (2666, 1212, "信州区", "Xinzhou"),
            (2667, 1212, "德兴市", "Dexing"),
            (2668, 1212, "上饶县", "Shangrao"),
            (2669, 1212, "广丰县", "Guangfeng"),
            (2670, 1212, "波阳县", "Boyang"),
            (2671, 1212, "婺源县", "Wuyuan"),
            (2672, 1212, "铅山县", "Qianshan"),
            (2673, 1212, "余干县", "Yugan"),
            (2674, 1212, "横峰县", "Hengfeng"),
            (2675, 1212, "弋阳县", "Yiyang"),
            (2676, 1212, "玉山县", "Yushan"),
            (2677, 1212, "万年县", "Wannian"),
            (2678, 1274, "市中区", "Shizhong"),
            (2679, 1274, "历下区", "Lixia"),
            (2680, 1274, "天桥区", "Tianqiao"),
            (2681, 1274, "槐荫区", "Huaiyin"),
            (2682, 1274, "历城区", "Licheng"),
            (2683, 1274, "长清区", "Changqing"),
            (2684, 1274, "章丘市", "Zhangqiu"),
            (2685, 1274, "平阴县", "Pingyin"),
            (2686, 1274, "济阳县", "Jiyang"),
            (2687, 1274, "商河县", "Shanghe"),
            (2688, 1263, "市南区", "Shinan"),
            (2689, 1263, "市北区", "Shibei"),
            (2690, 1263, "城阳区", "Changyang"),
            (2691, 1263, "四方区", "Sifang"),
            (2692, 1263, "李沧区", "Licang"),
            (2693, 1263, "黄岛区", "Huangdao"),
            (2694, 1263, "崂山区", "Laoshan"),
            (2695, 1263, "胶南市", "Jiaonan"),
            (2696, 1263, "胶州市", "Jiaozhou"),
            (2697, 1263, "平度市", "Pingdu"),
            (2698, 1263, "莱西市", "Laixi"),
            (2699, 1263, "即墨市", "Jimo"),
            (2700, 1276, "张店区", "Zhangdian"),
            (2701, 1276, "临淄区", "Linzi"),
            (2702, 1276, "淄川区", "Zichuan"),
            (2703, 1276, "博山区", "Boshan"),
            (2704, 1276, "周村区", "Zhoucun"),
            (2705, 1276, "桓台县", "Huaitai"),
            (2706, 1276, "高青县", "Gaoqing"),
            (2707, 1276, "沂源县", "Yiyuan"),
            (2708, 1269, "市中区", "Shizhong"),
            (2709, 1269, "山亭区", "Shanting"),
            (2710, 1269, "峄城区", "Yicheng"),
            (2711, 1269, "台儿庄区", "Taierzhuang"),
            (2712, 1269, "薛城区", "Xuecheng"),
            (2713, 1269, "滕州市", "Tengzhou"),
            (2714, 1272, "东营区", "Dongying"),
            (2715, 1272, "河口区", "Hekou"),
            (2716, 1272, "垦利县", "Kenli"),
            (2717, 1272, "广饶县", "Guangrao"),
            (2718, 1272, "利津县", "Lijin"),
            (2719, 1266, "潍城区", "Weicheng"),
            (2720, 1266, "寒亭区", "Hanting"),
            (2721, 1266, "坊子区", "Fangzi"),
            (2722, 1266, "奎文区", "Kuiwen"),
            (2723, 1266, "青州市", "Qingzhou"),
            (2724, 1266, "诸城市", "Zhucheng"),
            (2725, 1266, "寿光市", "Shouguang"),
            (2726, 1266, "安丘市", "Anqiu"),
            (2727, 1266, "高密市", "Gaomi"),
            (2728, 1266, "昌邑市", "Changyi"),
            (2729, 1266, "昌乐县", "Changle"),
            (2730, 1266, "临朐县", "Linqu"),
            (2731, 1268, "芝罘区", "Zhifu"),
            (2732, 1268, "福山区", "Fushan"),
            (2733, 1268, "牟平区", "Mouping"),
            (2734, 1268, "莱山区", "Laishan"),
            (2735, 1268, "龙口市", "Longkou"),
            (2736, 1268, "莱阳市", "Laiyang"),
            (2737, 1268, "莱州市", "Laizhou"),
            (2738, 1268, "招远市", "Zhaoyuan"),
            (2739, 1268, "蓬莱市", "Penglai"),
            (2740, 1268, "栖霞市", "Qixia"),
            (2741, 1268, "海阳市", "Haiyang"),
            (2742, 1268, "长岛县", "Changdao"),
            (2743, 1267, "环翠区", "Huancui"),
            (2744, 1267, "乳山市", "Lushan"),
            (2745, 1267, "文登市", "Wendeng"),
            (2746, 1267, "荣成市", "Rongcheng"),
            (2747, 1275, "市中区", "Shizhong"),
            (2748, 1275, "任城区", "Rencheng"),
            (2749, 1275, "曲阜市", "Qufu"),
            (2750, 1275, "兖州市", "Yanzhou"),
            (2751, 1275, "邹城市", "Zhoucheng"),
            (2752, 1275, "鱼台县", "Yutai"),
            (2753, 1275, "金乡县", "Jinxiang"),
            (2754, 1275, "嘉祥县", "Jiaxiang"),
            (2755, 1275, "微山县", "Weishan"),
            (2756, 1275, "汶上县", "Wenshang"),
            (2757, 1275, "泗水县", "Sishui"),
            (2758, 1275, "梁山县", "Liangshan"),
            (2759, 1265, "泰山区", "Taishan"),
            (2760, 1265, "岱岳区", "Daiyue"),
            (2761, 1265, "新泰市", "Xintai"),
            (2762, 1265, "肥城市", "Feicheng"),
            (2763, 1265, "宁阳县", "Ningyang"),
            (2764, 1265, "东平县", "Dongping"),
            (2765, 1264, "东港区", "Donggang"),
            (2766, 1264, "五莲县", "Wulian"),
            (2767, 1264, "莒县", "Juxian"),
            (2768, 1262, "莱城区", "Laicheng"),
            (2769, 1262, "钢城区", "Gangcheng"),
            (2770, 1271, "德城区", "Decheng"),
            (2771, 1271, "乐陵市", "Leling"),
            (2772, 1271, "禹城市", "Yucheng"),
            (2773, 1271, "陵县", "Lingxian"),
            (2774, 1271, "宁津县", "Ningjin"),
            (2775, 1271, "齐河县", "Jihe"),
            (2776, 1271, "武城县", "Wucheng"),
            (2777, 1271, "庆云县", "Qingyun"),
            (2778, 1271, "平原县", "Pingyuan"),
            (2779, 1271, "夏津县", "Xiajin"),
            (2780, 1271, "临邑县", "Linyi"),
            (2781, 1260, "兰山区", "Lanshan"),
            (2782, 1260, "罗庄区", "Luozhuang"),
            (2783, 1260, "河东区", "Hedong"),
            (2784, 1260, "沂南县", "Yinan"),
            (2785, 1260, "郯城县", "Taicheng"),
            (2786, 1260, "沂水县", "Yishui"),
            (2787, 1260, "苍山县", "Cangshan"),
            (2788, 1260, "费县", "Feixian"),
            (2789, 1260, "平邑县", "Pingyi"),
            (2790, 1260, "莒南县", "Junan"),
            (2791, 1260, "蒙阴县", "Mengyin"),
            (2792, 1260, "临沭县", "Linshu"),
            (2793, 1261, "东昌府区", "Dongchang"),
            (2794, 1261, "临清市", "Linqing"),
            (2795, 1261, "高唐县", "Gaotang"),
            (2796, 1261, "阳谷县", "Yanggu"),
            (2797, 1261, "茌平县", "Chiping"),
            (2798, 1261, "莘县", "Shenxian"),
            (2799, 1261, "东阿县", "Donge"),
            (2800, 1261, "冠县", "Guanxian"),
            (2801, 1270, "滨城区", "Bincheng"),
            (2802, 1270, "邹平县", "Zhouping"),
            (2803, 1270, "沾化县", "Zhanhua"),
            (2804, 1270, "惠民县", "Huimin"),
            (2805, 1270, "博兴县", "Boxing"),
            (2806, 1270, "阳信县", "Yangxin"),
            (2807, 1270, "无棣县", "Wudi"),
            (2808, 1273, "牡丹区", "Mudan"),
            (2809, 1273, "鄄城县", "Juancheng"),
            (2810, 1273, "单县", "Shanxian"),
            (2811, 1273, "郓城县", "Yuncheng"),
            (2812, 1273, "曹县", "Caoxian"),
            (2813, 1273, "定陶县", "Dingtao"),
            (2814, 1273, "巨野县", "Juye"),
            (2815, 1273, "东明县", "Dongming"),
            (2816, 1273, "成武县", "Chengwu"),
            (2817, 1143, "中原区", "Zhongyuan"),
            (2818, 1143, "金水区", "Jinshui"),
            (2819, 1143, "二七区", "Eiqi"),
            (2820, 1143, "管城回族区", "Quancheng"),
            (2821, 1143, "上街区", "Shangjie"),
            (2822, 1143, "邙山区", "Mangshan"),
            (2823, 1143, "巩义市", "Gongyi"),
            (2824, 1143, "新郑市", "Xinzheng"),
            (2825, 1143, "新密市", "Xinmi"),
            (2826, 1143, "登封市", "Dengfeng"),
            (2827, 1143, "荥阳市", "Xingyang"),
            (2828, 1143, "中牟县", "Zhongmou"),
            (2829, 1147, "鼓楼区", "Gulou"),
            (2830, 1147, "龙亭区", "Longting"),
            (2831, 1147, "顺河回族区", "Shunhe"),
            (2832, 1147, "南关区", "Nanguan"),
            (2833, 1147, "郊区", "Suburb"),
            (2834, 1147, "开封县", "Kaifeng"),
            (2835, 1147, "尉氏县", "Weishi"),
            (2836, 1147, "兰考县", "Lankao"),
            (2837, 1147, "杞县", "Qixian"),
            (2838, 1147, "通许县", "Tongxu"),
            (2839, 1132, "西工区", "Xigong"),
            (2840, 1132, "老城区", "Laocheng"),
            (2841, 1132, "涧西区", "Jianxi"),
            (2842, 1132, "瀍河回族区", "Chanhe"),
            (2843, 1132, "洛龙区", "Luolong"),
            (2844, 1132, "吉利区", "Jili"),
            (2845, 1132, "偃师市", "Yanshi"),
            (2846, 1132, "孟津县", "Mengjin"),
            (2847, 1132, "汝阳县", "Ruyang"),
            (2848, 1132, "伊川县", "Yichuan"),
            (2849, 1132, "洛宁县", "Luoning"),
            (2850, 1132, "嵩县", "Songxian"),
            (2851, 1132, "宜阳县", "Yiyang"),
            (2852, 1132, "新安县", "Xinan"),
            (2853, 1132, "栾川县", "Luanchuan"),
            (2854, 1141, "新华区", "Xinhua"),
            (2855, 1141, "卫东区", "Weidong"),
            (2856, 1141, "湛河区", "Zhanhe"),
            (2857, 1141, "石龙区", "Shilong"),
            (2858, 1141, "汝州市", "Ruzhou"),
            (2859, 1141, "舞钢市", "Wugang"),
            (2860, 1141, "宝丰县", "Baofeng"),
            (2861, 1141, "叶县", "Yexian"),
            (2862, 1141, "郏县", "Jiaxian"),
            (2863, 1141, "鲁山县", "Lushan"),
            (2864, 1146, "解放区", "Jiefang"),
            (2865, 1146, "中站区", "Zhongzhan"),
            (2866, 1146, "马村区", "Macun"),
            (2867, 1146, "山阳区", "Shanyang"),
            (2868, 1146, "沁阳市", "Qinyang"),
            (2869, 1146, "孟州市", "Mengzhou"),
            (2870, 1146, "修武县", "Xiuwu"),
            (2871, 1146, "温县", "Wenxian"),
            (2872, 1146, "武陟县", "Wuzhi"),
            (2873, 1146, "博爱县", "Boai"),
            (2874, 1145, "淇滨区", "Qibin"),
            (2875, 1145, "山城区", "Shancheng"),
            (2876, 1145, "鹤山区", "Heshan"),
            (2877, 1145, "浚县", "Junxian"),
            (2878, 1145, "淇县", "Qixian"),
            (2879, 1133, "新华区", "Xinhua"),
            (2880, 1133, "红旗区", "Hongqi"),
            (2881, 1133, "北站区", "Beizhan"),
            (2882, 1133, "郊区", "Suburb"),
            (2883, 1133, "卫辉市", "Weihui"),
            (2884, 1133, "辉县市", "Huixian"),
            (2885, 1133, "新乡县", "Xinxiang"),
            (2886, 1133, "获嘉县", "Huojia"),
            (2887, 1133, "原阳县", "Yuanyang"),
            (2888, 1133, "长垣县", "Chuangyuan"),
            (2889, 1133, "封丘县", "Fengqiu"),
            (2890, 1133, "延津县", "Yanjin"),
            (2891, 1144, "北关区", "Beiguan"),
            (2892, 1144, "文峰区", "Wenfeng"),
            (2893, 1144, "殷都区", "Yindu"),
            (2894, 1144, "龙安区", "Longan"),
            (2895, 1144, "林州市", "Linzhou"),
            (2896, 1144, "安阳县", "Anyang"),
            (2897, 1144, "滑县", "Huaxian"),
            (2898, 1144, "内黄县", "Neihuang"),
            (2899, 1144, "汤阴县", "Tangyin"),
            (2900, 1138, "华龙区", "Hualong"),
            (2901, 1138, "濮阳县", "Puyang"),
            (2902, 1138, "南乐县", "Nanle"),
            (2903, 1138, "台前县", "Taiqian"),
            (2904, 1138, "清丰县", "Qingfeng"),
            (2905, 1138, "范县", "Fanxian"),
            (2906, 1134, "魏都区", "Weidu"),
            (2907, 1134, "禹州市", "Yuzhou"),
            (2908, 1134, "长葛市", "Changge"),
            (2909, 1134, "许昌县", "Xuchang"),
            (2910, 1134, "鄢陵县", "Yanling"),
            (2911, 1134, "襄城县", "Xiangcheng"),
            (2912, 1139, "源汇区", "Yuanhui"),
            (2913, 1139, "郾城县", "Yancheng"),
            (2914, 1139, "临颍县", "Linying"),
            (2915, 1139, "舞阳县", "Wuyang"),
            (2916, 1137, "湖滨区", "Hubin"),
            (2917, 1137, "义马市", "Yima"),
            (2918, 1137, "灵宝市", "Lingbao"),
            (2919, 1137, "渑池县", "Mianchi"),
            (2920, 1137, "卢氏县", "Lushi"),
            (2921, 1137, "陕县", "Shanxian"),
            (2922, 1140, "卧龙区", "Wolong"),
            (2923, 1140, "宛城区", "Wancheng"),
            (2924, 1140, "邓州市", "Dengzhou"),
            (2925, 1140, "桐柏县", "Tongbai"),
            (2926, 1140, "方城县", "Fangcheng"),
            (2927, 1140, "淅川县", "Xichuan"),
            (2928, 1140, "镇平县", "Zhenping"),
            (2929, 1140, "唐河县", "Tanghe"),
            (2930, 1140, "南召县", "Nanzhao"),
            (2931, 1140, "内乡县", "Neixiang"),
            (2932, 1140, "新野县", "Xinye"),
            (2933, 1140, "社旗县", "Sheqi"),
            (2934, 1140, "西峡县", "Xixia"),
            (2935, 1136, "梁园区", "Liangyuan"),
            (2936, 1136, "睢阳区", "Suiyang"),
            (2937, 1136, "永城市", "Yongcheng"),
            (2938, 1136, "宁陵县", "Ningling"),
            (2939, 1136, "虞城县", "Yucheng"),
            (2940, 1136, "民权县", "Minquan"),
            (2941, 1136, "夏邑县", "Xiayi"),
            (2942, 1136, "柘城县", "Zhecheng"),
            (2943, 1136, "睢县", "Suixian"),
            (2944, 1135, "浉河区", "Shihe"),
            (2945, 1135, "平桥区", "Pingqiao"),
            (2946, 1135, "潢川县", "Huangchuan"),
            (2947, 1135, "淮滨县", "Huaibin"),
            (2948, 1135, "息县", "Xixian"),
            (2949, 1135, "新县", "Xinxian"),
            (2950, 1135, "商城县", "Shangcheng"),
            (2951, 1135, "固始县", "Gushi"),
            (2952, 1135, "罗山县", "Luoshan"),
            (2953, 1135, "光山县", "Guangshan"),
            (2954, 1142, "川汇区", "Chuanhui"),
            (2955, 1142, "项城市", "Dingcheng"),
            (2956, 1142, "商水县", "Shangshui"),
            (2957, 1142, "淮阳县", "Huaiyang"),
            (2958, 1142, "太康县", "Taikang"),
            (2959, 1142, "鹿邑县", "Luyi"),
            (2960, 1142, "西华县", "Xihua"),
            (2961, 1142, "扶沟县", "Fugou"),
            (2962, 1142, "沈丘县", "Shenqiu"),
            (2963, 1142, "郸城县", "Dancheng"),
            (2964, 1148, "驿城区", "Yicheng"),
            (2965, 1148, "确山县", "Queshan"),
            (2966, 1148, "新蔡县", "Xincai"),
            (2967, 1148, "上蔡县", "Shangcai"),
            (2968, 1148, "西平县", "Xiping"),
            (2969, 1148, "泌阳县", "Biyang"),
            (2970, 1148, "平舆县", "Pingyu"),
            (2971, 1148, "汝南县", "Runan"),
            (2972, 1148, "遂平县", "Suiping"),
            (2973, 1148, "正阳县", "Zhengyang"),
            (2974, 1408, "济源市", "Jiyuan"),
            (2975, 1167, "江岸区", "Jiangan"),
            (2976, 1167, "武昌区", "Wuchang"),
            (2977, 1167, "江汉区", "Jianghan"),
            (2978, 1167, "硚口区", "Qiaokou"),
            (2979, 1167, "汉阳区", "Hanyang"),
            (2980, 1167, "青山区", "Qingshan"),
            (2981, 1167, "洪山区", "Hongshan"),
            (2982, 1167, "东西湖区", "Dongxihu"),
            (2983, 1167, "汉南区", "Hannan"),
            (2984, 1167, "蔡甸区", "Caidian"),
            (2985, 1167, "江夏区", "Jiangxia"),
            (2986, 1167, "黄陂区", "Huangpi"),
            (2987, 1167, "新洲区", "Xinzhou"),
            (2988, 1171, "黄石港区", "Huangshigang"),
            (2989, 1171, "石灰窑区", "Shihuiyao"),
            (2990, 1171, "下陆区", "Xialu"),
            (2991, 1171, "铁山区", "Tieshan"),
            (2992, 1171, "大冶市", "Daye"),
            (2993, 1171, "阳新县", "Yangxin"),
            (2994, 1166, "襄城区", "Xiangcheng"),
            (2995, 1166, "樊城区", "Fancheng"),
            (2996, 1166, "襄阳区", "Xiangyang"),
            (2997, 1166, "老河口市", "Laohekou"),
            (2998, 1166, "枣阳市", "Zaoyang"),
            (2999, 1166, "宜城市", "Yicheng"),
            (3000, 1166, "南漳县", "Nanzhang"),
            (3001, 1166, "谷城县", "Gucheng"),
            (3002, 1166, "保康县", "Baokang"),
            (3003, 1164, "张湾区", "Zhangwan"),
            (3004, 1164, "茅箭区", "Maojian"),
            (3005, 1164, "丹江口市", "Danjiangkou"),
            (3006, 1164, "郧县", "Yunxian"),
            (3007, 1164, "竹山县", "Zhushan"),
            (3008, 1164, "房县", "Fangxian"),
            (3009, 1164, "郧西县", "Yunxi"),
            (3010, 1164, "竹溪县", "Zhuxi"),
            (3011, 1174, "沙市区", "Shashi"),
            (3012, 1174, "荆州区", "Jingzhou"),
            (3013, 1174, "洪湖市", "Honghu"),
            (3014, 1174, "石首市", "Shishou"),
            (3015, 1174, "松滋市", "Songzi"),
            (3016, 1174, "监利县", "Jianli"),
            (3017, 1174, "公安县", "Gongan"),
            (3018, 1174, "江陵县", "Jiangling"),
            (3019, 1168, "西陵区", "Xiling"),
            (3020, 1168, "伍家岗区", "Wujiagang"),
            (3021, 1168, "点军区", "Dianjun"),
            (3022, 1168, "猇亭区", "Xiaoting"),
            (3023, 1168, "夷陵区", "Yiling"),
            (3024, 1168, "宜都市", "Yidu"),
            (3025, 1168, "当阳市", "Dangyang"),
            (3026, 1168, "枝江市", "Zhijiang"),
            (3027, 1168, "秭归县", "Zigui"),
            (3028, 1168, "远安县", "Yuanan"),
            (3029, 1168, "兴山县", "Xingshan"),
            (3030, 1168, "五峰土家族自治县", "Wufeng"),
            (3031, 1168, "长阳土家族自治县", "Changyang"),
            (3032, 1173, "东宝区", "Dongbao"),
            (3033, 1173, "掇刀区", "Duodao"),
            (3034, 1173, "钟祥市", "Zhongxiang"),
            (3035, 1173, "京山县", "Jingshan"),
            (3036, 1173, "沙洋县", "Shayang"),
            (3037, 1169, "鄂城区", "Echeng"),
            (3038, 1169, "华容区", "Huarong"),
            (3039, 1169, "梁子湖区", "Liangzihu"),
            (3040, 1162, "孝南区", "Xiaonan"),
            (3041, 1162, "应城市", "Yingcheng"),
            (3042, 1162, "安陆市", "Anlu"),
            (3043, 1162, "汉川市", "Hanchuan"),
            (3044, 1162, "云梦县", "Yunmeng"),
            (3045, 1162, "大悟县", "Dawu"),
            (3046, 1162, "孝昌县", "Xiaochang"),
            (3047, 1172, "黄州区", "Huangzhou"),
            (3048, 1172, "麻城市", "Macheng"),
            (3049, 1172, "武穴市", "Wuxue"),
            (3050, 1172, "红安县", "Hongan"),
            (3051, 1172, "罗田县", "Luotian"),
            (3052, 1172, "浠水县", "Xishui"),
            (3053, 1172, "蕲春县", "Qichun"),
            (3054, 1172, "黄梅县", "Huangmei"),
            (3055, 1172, "英山县", "Yingshan"),
            (3056, 1172, "团风县", "Tuofeng"),
            (3057, 1165, "咸安区", "Xianan"),
            (3058, 1165, "赤壁市", "Chibi"),
            (3059, 1165, "嘉鱼县", "Jiayu"),
            (3060, 1165, "通山县", "Tongshan"),
            (3061, 1165, "崇阳县", "Chongyang"),
            (3062, 1165, "通城县", "Tongcheng"),
            (3063, 1163, "曾都区", "Zengdu"),
            (3064, 1163, "广水市", "Guangshui"),
            (3065, 1412, "仙桃市", "Xiantao"),
            (3066, 1411, "天门市", "Tianmen"),
            (3067, 1409, "潜江市", "Qianjiang"),
            (3068, 1410, "神农架林区", "Shennongjia"),
            (3069, 1170, "恩施市", "Shien"),
            (3070, 1170, "利川市", "Lichuan"),
            (3071, 1170, "建始县", "Jianshi"),
            (3072, 1170, "来凤县", "Laifeng"),
            (3073, 1170, "巴东县", "Badong"),
            (3074, 1170, "鹤峰县", "Hefeng"),
            (3075, 1170, "宣恩县", "Xuanen"),
            (3076, 1170, "咸丰县", "Xianfeng"),
            (3077, 1185, "岳麓区", "Yuelu"),
            (3078, 1185, "芙蓉区", "Furong"),
            (3079, 1185, "天心区", "Tianxin"),
            (3080, 1185, "开福区", "Kaifu"),
            (3081, 1185, "雨花区", "Yuhua"),
            (3082, 1185, "浏阳市", "Liuyang"),
            (3083, 1185, "长沙县", "Changsha"),
            (3084, 1185, "望城县", "Wangcheng"),
            (3085, 1185, "宁乡县", "Ningxiang"),
            (3086, 1183, "天元区", "Tianyuan"),
            (3087, 1183, "荷塘区", "Hetang"),
            (3088, 1183, "芦淞区", "Lusong"),
            (3089, 1183, "石峰区", "Shifeng"),
            (3090, 1183, "醴陵市", "Liling"),
            (3091, 1183, "株洲县", "Zhuzhou"),
            (3092, 1183, "炎陵县", "Yanling"),
            (3093, 1183, "茶陵县", "Chaling"),
            (3094, 1183, "攸县", "Youxian"),
            (3095, 1177, "雨湖区", "Yuhu"),
            (3096, 1177, "岳塘区", "Yuetang"),
            (3097, 1177, "湘乡市", "Xiangxiang"),
            (3098, 1177, "韶山市", "Shaoshan"),
            (3099, 1177, "湘潭县", "Xiangtan"),
            (3100, 1187, "石鼓区", "Shigu"),
            (3101, 1187, "雁峰区", "Yanfeng"),
            (3102, 1187, "珠晖区", "Zhuhui"),
            (3103, 1187, "蒸湘区", "Zhengxiang"),
            (3104, 1187, "南岳区", "Nanyue"),
            (3105, 1187, "耒阳市", "Leiyang"),
            (3106, 1187, "常宁市", "Changning"),
            (3107, 1187, "衡阳县", "Hengyang"),
            (3108, 1187, "衡东县", "Hengdong"),
            (3109, 1187, "衡山县", "Hengshan"),
            (3110, 1187, "衡南县", "Hengnan"),
            (3111, 1187, "祁东县", "Qidong"),
            (3112, 1176, "双清区", "Shuangqing"),
            (3113, 1176, "大祥区", "Daxiang"),
            (3114, 1176, "北塔区", "Beita"),
            (3115, 1176, "武冈市", "Wugang"),
            (3116, 1176, "邵东县", "Shaodong"),
            (3117, 1176, "洞口县", "Dongkou"),
            (3118, 1176, "新邵县", "Xinshao"),
            (3119, 1176, "绥宁县", "Suining"),
            (3120, 1176, "新宁县", "Xinning"),
            (3121, 1176, "邵阳县", "Shaoyang"),
            (3122, 1176, "隆回县", "Longhui"),
            (3123, 1176, "城步苗族自治县", "Chengbu"),
            (3124, 1179, "岳阳楼区", "Yueyanglou"),
            (3125, 1179, "君山区", "Junshan"),
            (3126, 1179, "云溪区", "Yunxi"),
            (3127, 1179, "临湘市", "Linxiang"),
            (3128, 1179, "汨罗市", "Miluo"),
            (3129, 1179, "岳阳县", "Yueyang"),
            (3130, 1179, "湘阴县", "Xiangyin"),
            (3131, 1179, "平江县", "Pingjiang"),
            (3132, 1179, "华容县", "Huarong"),
            (3133, 1184, "武陵区", "Wuling"),
            (3134, 1184, "鼎城区", "Dingcheng"),
            (3135, 1184, "津市市", "Jinshi"),
            (3136, 1184, "澧县", "Lixian"),
            (3137, 1184, "临澧县", "Linli"),
            (3138, 1184, "桃源县", "Taoyuan"),
            (3139, 1184, "汉寿县", "Hanshou"),
            (3140, 1184, "安乡县", "Anxiang"),
            (3141, 1184, "石门县", "Shimen"),
            (3142, 1181, "永定区", "Yongding"),
            (3143, 1181, "武陵源区", "Wulingyuan"),
            (3144, 1181, "慈利县", "Cili"),
            (3145, 1181, "桑植县", "Sangzhi"),
            (3146, 1182, "赫山区", "Heshan"),
            (3147, 1182, "资阳区", "Ziyang"),
            (3148, 1182, "沅江市", "Yuanjiang"),
            (3149, 1182, "桃江县", "Taojiang"),
            (3150, 1182, "南县", "Nanxian"),
            (3151, 1182, "安化县", "Anhua"),
            (3152, 1186, "北湖区", "Beihu"),
            (3153, 1186, "苏仙区", "Suxian"),
            (3154, 1186, "资兴市", "Zixing"),
            (3155, 1186, "宜章县", "Yizhang"),
            (3156, 1186, "汝城县", "Rucheng"),
            (3157, 1186, "安仁县", "Anren"),
            (3158, 1186, "嘉禾县", "Jiahe"),
            (3159, 1186, "临武县", "Linwu"),
            (3160, 1186, "桂东县", "Guidong"),
            (3161, 1186, "永兴县", "Yongxing"),
            (3162, 1186, "桂阳县", "Guiyang"),
            (3163, 1180, "冷水滩区", "Lengshuitan"),
            (3164, 1180, "芝山区", "Zhishan"),
            (3165, 1180, "祁阳县", "Qiyang"),
            (3166, 1180, "蓝山县", "Lanshan"),
            (3167, 1180, "宁远县", "Ningyuan"),
            (3168, 1180, "新田县", "Xintian"),
            (3169, 1180, "东安县", "Dongan"),
            (3170, 1180, "江永县", "Jiangyong"),
            (3171, 1180, "道县", "Daoxian"),
            (3172, 1180, "双牌县", "Shuangpai"),
            (3173, 1180, "江华瑶族自治县", "Jianghua"),
            (3174, 1188, "鹤城区", "Hecheng"),
            (3175, 1188, "洪江市", "Hongjiang"),
            (3176, 1188, "会同县", "Huitong"),
            (3177, 1188, "沅陵县", "Yuanling"),
            (3178, 1188, "辰溪县", "Chenxi"),
            (3179, 1188, "溆浦县", "Xupu"),
            (3180, 1188, "中方县", "Zhongfang"),
            (3181, 1188, "新晃侗族自治县", "Xinhuang"),
            (3182, 1188, "芷江侗族自治县", "Zhijiang"),
            (3183, 1188, "通道侗族自治县", "Tongdao"),
            (3184, 1188, "靖州苗族侗族自治县", "Jingzhou"),
            (3185, 1188, "麻阳苗族自治县", "Mayang"),
            (3186, 1175, "娄星区", "Louxing"),
            (3187, 1175, "冷水江市", "Lengshuijiang"),
            (3188, 1175, "涟源市", "Lianyuan"),
            (3189, 1175, "新化县", "Xinhua"),
            (3190, 1175, "双峰县", "Shuangfeng"),
            (3191, 1178, "吉首市", "Jishou"),
            (3192, 1178, "古丈县", "Guzhang"),
            (3193, 1178, "龙山县", "Longshan"),
            (3194, 1178, "永顺县", "Yongshun"),
            (3195, 1178, "凤凰县", "Fenghuang"),
            (3196, 1178, "泸溪县", "Luxi"),
            (3197, 1178, "保靖县", "Baojing"),
            (3198, 1178, "花垣县", "Huayuan"),
            (3199, 1091, "越秀区", "Yuexiu"),
            (3200, 1091, "东山区", "Dongshan"),
            (3201, 1091, "海珠区", "Haizhu"),
            (3202, 1091, "荔湾区", "Liwan"),
            (3203, 1091, "天河区", "Tianhe"),
            (3204, 1091, "白云区", "Baiyun"),
            (3205, 1091, "黄埔区", "Huangpu"),
            (3206, 1091, "芳村区", "Fangcun"),
            (3207, 1091, "花都区", "Huadu"),
            (3208, 1091, "番禺区", "Fanyu"),
            (3209, 1091, "从化市", "Conghua"),
            (3210, 1091, "增城市", "Zengcheng"),
            (3211, 1079, "福田区", "Futian"),
            (3212, 1079, "罗湖区", "Luohu"),
            (3213, 1079, "南山区", "Nanshan"),
            (3214, 1079, "宝安区", "Baoan"),
            (3215, 1079, "龙岗区", "Longgang"),
            (3216, 1079, "盐田区", "Yantian"),
            (3217, 1087, "香洲区", "Xiangzhou"),
            (3218, 1087, "斗门区", "Doumen"),
            (3219, 1087, "金湾区", "Jinwan"),
            (3220, 1078, "潮阳区", "Chaoyang"),
            (3221, 1078, "潮南区", "Chaonan"),
            (3222, 1078, "澄海区", "Chenghai"),
            (3223, 1078, "濠江区", "Haojiang"),
            (3224, 1078, "金平区", "Jinping"),
            (3225, 1078, "龙湖区", "Longhu"),
            (3226, 1078, "南澳县", "Nanao"),
            (3227, 1081, "北江区", "Beijiang"),
            (3228, 1081, "浈江区", "Zhenjiang"),
            (3229, 1081, "武江区", "Wujiang"),
            (3230, 1081, "乐昌市", "Lechang"),
            (3231, 1081, "南雄市", "Nanxiong"),
            (3232, 1081, "仁化县", "Renhua"),
            (3233, 1081, "始兴县", "Shixing"),
            (3234, 1081, "翁源县", "Wengyuan"),
            (3235, 1081, "曲江县", "Qujiang"),
            (3236, 1081, "新丰县", "Xinfeng"),
            (3237, 1081, "乳源瑶族自治县", "Luyuan"),
            (3238, 1092, "源城区", "Yuancheng"),
            (3239, 1092, "和平县", "Heping"),
            (3240, 1092, "龙川县", "Longchuan"),
            (3241, 1092, "紫金县", "Zijin"),
            (3242, 1092, "连平县", "Lianping"),
            (3243, 1092, "东源县", "Dongyuan"),
            (3244, 1075, "梅江区", "Meijiang"),
            (3245, 1075, "兴宁市", "Xingning"),
            (3246, 1075, "梅县", "Meixian"),
            (3247, 1075, "蕉岭县", "Jiaoling"),
            (3248, 1075, "大埔县", "Dabu"),
            (3249, 1075, "丰顺县", "Fengshun"),
            (3250, 1075, "五华县", "Wuhua"),
            (3251, 1075, "平远县", "Pingyuan"),
            (3252, 1093, "惠城区", "Huicheng"),
            (3253, 1093, "惠阳市", "Huiyang"),
            (3254, 1093, "惠东县", "Huidong"),
            (3255, 1093, "博罗县", "Boluo"),
            (3256, 1093, "龙门县", "Longmen"),
            (3257, 1077, "城区", "Urban Area"),
            (3258, 1077, "陆丰市", "Lufeng"),
            (3259, 1077, "海丰县", "Haifeng"),
            (3260, 1077, "陆河县", "Luhe"),
            (3261, 1089, "东莞市", "Dongguan"),
            (3262, 1086, "中山市", "Zhongshan"),
            (3263, 1095, "江海区", "Jianghai"),
            (3264, 1095, "蓬江区", "Pengjiang"),
            (3265, 1095, "新会区", "Xinhui"),
            (3266, 1095, "台山市", "Taishan"),
            (3267, 1095, "开平市", "Kaiping"),
            (3268, 1095, "鹤山市", "Heshan"),
            (3269, 1095, "恩平市", "Enping"),
            (3270, 1090, "顺德区", "Shunde"),
            (3271, 1090, "南海区", "Nanhai"),
            (3272, 1090, "三水区", "Shanshui"),
            (3273, 1090, "高明区", "Gaoming"),
            (3274, 1090, "禅城区", "Chancheng"),
            (3275, 1082, "江城区", "Jiangcheng"),
            (3276, 1082, "阳春市", "Yangchun"),
            (3277, 1082, "阳西县", "Yangxi"),
            (3278, 1082, "阳东县", "Yangdong"),
            (3279, 1084, "赤坎区", "Chikan"),
            (3280, 1084, "霞山区", "Xiashan"),
            (3281, 1084, "坡头区", "Potou"),
            (3282, 1084, "麻章区", "Mazhang"),
            (3283, 1084, "廉江市", "Lianjiang"),
            (3284, 1084, "雷州市", "Leizhou"),
            (3285, 1084, "吴川市", "Wuchuan"),
            (3286, 1084, "遂溪县", "Suixi"),
            (3287, 1084, "徐闻县", "Xuwen"),
            (3288, 1074, "茂南区", "Maonan"),
            (3289, 1074, "茂港区", "Maogang"),
            (3290, 1074, "高州市", "Gaozhou"),
            (3291, 1074, "化州市", "Huazhou"),
            (3292, 1074, "信宜市", "Xinyi"),
            (3293, 1074, "电白县", "Dianbai"),
            (3294, 1085, "端州区", "Duanzhou"),
            (3295, 1085, "鼎湖区", "Dinghu"),
            (3296, 1085, "高要市", "Gaoyao"),
            (3297, 1085, "四会市", "Sihui"),
            (3298, 1085, "广宁县", "Guangning"),
            (3299, 1085, "德庆县", "Deqing"),
            (3300, 1085, "封开县", "Fengkai"),
            (3301, 1085, "怀集县", "Huaiji"),
            (3302, 1076, "清城区", "Qingcheng"),
            (3303, 1076, "英德市", "Yingde"),
            (3304, 1076, "连州市", "Lianzhou"),
            (3305, 1076, "佛冈县", "Fogang"),
            (3306, 1076, "阳山县", "Yangshan"),
            (3307, 1076, "清新县", "Qingxin"),
            (3308, 1076, "连山壮族瑶族自治县", "Lianshan"),
            (3309, 1076, "连南瑶族自治县", "Liannan"),
            (3310, 1088, "湘桥区", "Xiangqiao"),
            (3311, 1088, "潮安县", "Chaoan"),
            (3312, 1088, "饶平县", "Raoping"),
            (3313, 1094, "榕城区", "Rongcheng"),
            (3314, 1094, "普宁市", "Puning"),
            (3315, 1094, "揭东县", "Jiedong"),
            (3316, 1094, "揭西县", "Jiexi"),
            (3317, 1094, "惠来县", "Huilai"),
            (3318, 1083, "云城区", "Yuncheng"),
            (3319, 1083, "罗定市", "Luoding"),
            (3320, 1083, "云安县", "Yunan"),
            (3321, 1083, "新兴县", "Xinxing"),
            (3322, 1083, "郁南县", "Yunan"),
            (3324, 1120, "秀英区", "Xiuying"),
            (3325, 1120, "龙华区", "Longhua"),
            (3326, 1120, "琼山区", "Qiongshan"),
            (3327, 1120, "美兰区", "Meilan"),
            (3328, 1119, "三亚市", "Sanya"),
            (3329, 1406, "五指山市", "Wuzhishan"),
            (3330, 1401, "琼海市", "Qionghai"),
            (3331, 1407, "儋州市", "Danzhou"),
            (3332, 3323, "琼山市", "Qiongshan"),
            (3333, 1405, "文昌市", "Wenchang"),
            (3334, 1404, "万宁市", "Wanning"),
            (3335, 1397, "东方市", "Dongfang"),
            (3336, 1395, "澄迈县", "Chengmai"),
            (3337, 1396, "定安县", "Anding"),
            (3338, 1403, "屯昌县", "Tunchang"),
            (3339, 1399, "临高县", "Lingao"),
            (3340, 1392, "白沙黎族自治县", "Baisha"),
            (3341, 1394, "昌江黎族自治县", "Changjiang"),
            (3342, 1398, "乐东黎族自治县", "Ledong"),
            (3343, 1400, "陵水黎族自治县", "Lingshui"),
            (3344, 1393, "保亭黎族苗族自治县", "Baoting"),
            (3345, 1402, "琼中黎族苗族自治县", "Qiongzhong"),
            (3346, 1101, "新城区", "Xincheng"),
            (3347, 1101, "兴宁区", "Xingning"),
            (3348, 1101, "永新区", "Yongxin"),
            (3349, 1101, "城北区", "Chengbei"),
            (3350, 1101, "江南区", "Jiangnan"),
            (3351, 1101, "邕宁县", "Yongning"),
            (3352, 1101, "武鸣县", "Wuming"),
            (3353, 1101, "隆安县", "Longan"),
            (3354, 1101, "马山县", "Mashan"),
            (3355, 1101, "上林县", "Shanglin"),
            (3356, 1101, "宾阳县", "Binyang"),
            (3357, 1101, "横县", "Hengxian"),
            (3358, 1096, "城中区", "Chengzhong"),
            (3359, 1096, "鱼峰区", "Yufeng"),
            (3360, 1096, "柳北区", "Liubei"),
            (3361, 1096, "柳南区", "Liunan"),
            (3362, 1096, "市郊区", "Suburb"),
            (3363, 1096, "柳江县", "Liujiang"),
            (3364, 1096, "柳城县", "Liucheng"),
            (3365, 1096, "融水苗族自治县", "Rongshui"),
            (3366, 1096, "鹿寨县", "Luzhai"),
            (3367, 1096, "融安县", "Rongan"),
            (3368, 1096, "三江侗族自治县", "Sanjiang"),
            (3369, 1106, "秀峰区", "Xiufeng"),
            (3370, 1106, "叠彩区", "Diecai"),
            (3371, 1106, "象山区", "Xiangshan"),
            (3372, 1106, "七星区", "Qixing"),
            (3373, 1106, "雁山区", "Yanshan"),
            (3374, 1106, "阳朔县", "Yangshuo"),
            (3375, 1106, "临桂县", "Lingui"),
            (3376, 1106, "灵川县", "Lingchuan"),
            (3377, 1106, "全州县", "Quanzhou"),
            (3378, 1106, "平乐县", "Pingle"),
            (3379, 1106, "兴安县", "Xingan"),
            (3380, 1106, "灌阳县", "Guanyang"),
            (3381, 1106, "荔浦县", "Lipu"),
            (3382, 1106, "资源县", "Ziyuan"),
            (3383, 1106, "永福县", "Yongfu"),
            (3384, 1106, "龙胜各族自治县", "Longsheng"),
            (3385, 1106, "恭城瑶族自治县", "Gongcheng"),
            (3386, 1099, "万秀区", "Wanxiu"),
            (3387, 1099, "蝶山区", "Dieshan"),
            (3388, 1099, "市郊区", "Suburb"),
            (3389, 1099, "岑溪市", "Cenxi"),
            (3390, 1099, "苍梧县", "Cangwu"),
            (3391, 1099, "藤县", "Tengxian"),
            (3392, 1099, "蒙山县", "Mengshan"),
            (3393, 1104, "海城区", "Haicheng"),
            (3394, 1104, "银海区", "Yinhai"),
            (3395, 1104, "铁山港区", "Tieshangang"),
            (3396, 1104, "合浦县", "Hepu"),
            (3397, 1105, "港口区", "Gangkou"),
            (3398, 1105, "防城区", "Fangcheng"),
            (3399, 1105, "东兴市", "Dongxing"),
            (3400, 1105, "上思县", "Shangsi"),
            (3401, 1098, "钦南区", "Qinnan"),
            (3402, 1098, "钦北区", "Qinbei"),
            (3403, 1098, "灵山县", "Lingshan"),
            (3404, 1098, "浦北县", "Pubei"),
            (3405, 1107, "港北区", "Gangbei"),
            (3406, 1107, "港南区", "Gangnan"),
            (3407, 1107, "桂平市", "Guiping"),
            (3408, 1107, "平南县", "Pingnan"),
            (3409, 1100, "玉州区", "Yuzhou"),
            (3410, 1100, "北流市", "Beiliu"),
            (3411, 1100, "容县", "Rongxian"),
            (3412, 1100, "陆川县", "Luchuan"),
            (3413, 1100, "博白县", "Bobai"),
            (3414, 1100, "兴业县", "Xingye"),
            (3415, 1097, "江洲区", "Jiangzhou"),
            (3416, 1097, "宁明县", "Ningming"),
            (3417, 1097, "扶绥县", "Fusui"),
            (3418, 1097, "龙州县", "Longzhou"),
            (3419, 1097, "大新县", "Daxin"),
            (3420, 1097, "天等县", "Tiandeng"),
            (3421, 1413, "凭祥市", "Pingxiang"),
            (3422, 1102, "合山市", "Heshan"),
            (3423, 1102, "兴宾区", "Xingbin"),
            (3424, 1102, "象州县", "Xiangzhou"),
            (3425, 1102, "武宣县", "Wuxuan"),
            (3426, 1102, "忻城县", "Xincheng"),
            (3427, 1102, "金秀瑶族自治县", "Jinxiu"),
            (3428, 1109, "贺州市", "Hezhou"),
            (3429, 1109, "钟山县", "Zhongshan"),
            (3430, 1109, "昭平县", "Zhaoping"),
            (3431, 1109, "富川瑶族自治县", "Fuchuan"),
            (3432, 1103, "凌云县", "Lingyun"),
            (3433, 1103, "平果县", "Pingguo"),
            (3434, 1103, "西林县", "Xilin"),
            (3435, 1103, "乐业县", "Leye"),
            (3436, 1103, "德保县", "Debao"),
            (3437, 1103, "田林县", "Tianlin"),
            (3438, 1103, "田阳县", "Tianyang"),
            (3439, 1103, "靖西县", "Jingxi"),
            (3440, 1103, "田东县", "Tiandong"),
            (3441, 1103, "那坡县", "Napo"),
            (3442, 1103, "隆林各族自治县", "Longlin"),
            (3443, 1108, "河池市", "Hechi"),
            (3444, 1108, "宜州市", "Yizhou"),
            (3445, 1108, "天峨县", "Tiane"),
            (3446, 1108, "凤山县", "Fengshan"),
            (3447, 1108, "南丹县", "Nandan"),
            (3448, 1108, "东兰县", "Donglan"),
            (3449, 1108, "都安瑶族自治县", "Duan"),
            (3450, 1108, "罗城仡佬族自治县", "Luocheng"),
            (3451, 1108, "巴马瑶族自治县", "Bama"),
            (3452, 1108, "环江毛南族自治县", "Huanjiang"),
            (3453, 1108, "大化瑶族自治县", "Dahua"),
            (3454, 1311, "青羊区", "Qingyang"),
            (3455, 1311, "锦江区", "Jinjiang"),
            (3456, 1311, "金牛区", "Jinniu"),
            (3457, 1311, "武侯区", "Wuhou"),
            (3458, 1311, "成华区", "Chenghua"),
            (3459, 1311, "龙泉驿区", "Longquanyi"),
            (3460, 1311, "青白江区", "Qingbaijiang"),
            (3461, 1311, "新都区", "Xindu"),
            (3462, 1311, "都江堰市", "Dujiangyan"),
            (3463, 1311, "彭州市", "Pengzhou"),
            (3464, 1311, "邛崃市", "Qionglai"),
            (3465, 1311, "崇州市", "Chongzhou"),
            (3466, 1311, "金堂县", "Jintang"),
            (3467, 1311, "温江区", "Wenjiang"),
            (3468, 1311, "郫县", "Pixian"),
            (3469, 1311, "新津县", "Xinjin"),
            (3470, 1311, "双流县", "Shuangliu"),
            (3471, 1311, "蒲江县", "Pujiang"),
            (3472, 1311, "大邑县", "Dayi"),
            (3473, 1318, "大安区", "Daan"),
            (3474, 1318, "自流井区", "Ziliujing"),
            (3475, 1318, "贡井区", "Gongjing"),
            (3476, 1318, "沿滩区", "Yantan"),
            (3477, 1318, "荣县", "Rongxian"),
            (3478, 1318, "富顺县", "Fushun"),
            (3479, 1306, "东区", "Dongqu"),
            (3480, 1306, "西区", "Xiqu"),
            (3481, 1306, "仁和区", "Renhe"),
            (3482, 1306, "米易县", "Miyi"),
            (3483, 1306, "盐边县", "Yanbian"),
            (3484, 1299, "江阳区", "Jiangyang"),
            (3485, 1299, "纳溪区", "Naxi"),
            (3486, 1299, "龙马潭区", "Longmatan"),
            (3487, 1299, "泸县", "Luxian"),
            (3488, 1299, "合江县", "Hejiang"),
            (3489, 1299, "叙永县", "Xuyong"),
            (3490, 1299, "古蔺县", "Gulin"),
            (3491, 1313, "旌阳区", "Jingyang"),
            (3492, 1313, "广汉市", "Guanghan"),
            (3493, 1313, "什邡市", "Shifang"),
            (3494, 1313, "绵竹市", "Mianzhu"),
            (3495, 1313, "罗江县", "Luojiang"),
            (3496, 1313, "中江县", "Zhongjiang"),
            (3497, 1298, "涪城区", "Fucheng"),
            (3498, 1298, "游仙区", "Youxian"),
            (3499, 1298, "江油市", "Jiangyou"),
            (3500, 1298, "盐亭县", "Yanting"),
            (3501, 1298, "三台县", "Santai"),
            (3502, 1298, "平武县", "Pingwu"),
            (3503, 1298, "北川县", "Beichuan"),
            (3504, 1298, "安县", "Anxian"),
            (3505, 1298, "梓潼县", "Zitong"),
            (3506, 1315, "市中区", "Shizhong"),
            (3507, 1315, "元坝区", "Yuanba"),
            (3508, 1315, "朝天区", "Chaotian"),
            (3509, 1315, "青川县", "Qingchuan"),
            (3510, 1315, "旺苍县", "Wangcang"),
            (3511, 1315, "剑阁县", "Jiange"),
            (3512, 1315, "苍溪县", "Cangxi"),
            (3513, 1303, "市中区", "Shizhong"),
            (3514, 1303, "射洪县", "Shehong"),
            (3515, 1303, "蓬溪县", "Pengxi"),
            (3516, 1303, "大英县", "Daying"),
            (3517, 1308, "市中区", "Shizhong"),
            (3518, 1308, "东兴区", "Dongxing"),
            (3519, 1308, "资中县", "Zizhong"),
            (3520, 1308, "隆昌县", "Longchang"),
            (3521, 1308, "威远县", "Weiyuan"),
            (3522, 1300, "市中区", "Shizhong"),
            (3523, 1300, "五通桥区", "Wutongqiao"),
            (3524, 1300, "沙湾区", "Shawan"),
            (3525, 1300, "金口河区", "Jinkouhe"),
            (3526, 1300, "峨眉山市", "Emeishan"),
            (3527, 1300, "夹江县", "Jiajiang"),
            (3528, 1300, "井研县", "Jingyan"),
            (3529, 1300, "犍为县", "Qianwei"),
            (3530, 1300, "沐川县", "Muchuan"),
            (3531, 1300, "马边彝族自治县", "Mabian"),
            (3532, 1300, "峨边彝族自治县", "Ebian"),
            (3533, 1307, "顺庆区", "Shunqing"),
            (3534, 1307, "高坪区", "Gaoping"),
            (3535, 1307, "嘉陵区", "Jialing"),
            (3536, 1307, "阆中市", "Langzhong"),
            (3537, 1307, "营山县", "Yingshan"),
            (3538, 1307, "蓬安县", "Pengan"),
            (3539, 1307, "仪陇县", "Yilong"),
            (3540, 1307, "南部县", "Nanbu"),
            (3541, 1307, "西充县", "Xichong"),
            (3542, 1305, "翠屏区", "Cuiping"),
            (3543, 1305, "宜宾县", "Yibin"),
            (3544, 1305, "兴文县", "Xingwen"),
            (3545, 1305, "南溪县", "Nanxi"),
            (3546, 1305, "珙县", "Gongxian"),
            (3547, 1305, "江安县", "Jiangan"),
            (3548, 1305, "筠连县", "Junlian"),
            (3549, 1305, "屏山县", "Pingshan"),
            (3550, 1305, "长宁县", "Changning"),
            (3551, 1305, "高县", "Gaoxian"),
            (3552, 1316, "广安区", "Guangan"),
            (3553, 1316, "华蓥市", "Huaying"),
            (3554, 1316, "岳池县", "Yuechi"),
            (3555, 1316, "邻水县", "Lingshui"),
            (3556, 1316, "武胜县", "Wusheng"),
            (3557, 1312, "通川区", "Tongchuan"),
            (3558, 1312, "万源市", "Wanyuan"),
            (3559, 1312, "达县", "Daxian"),
            (3560, 1312, "渠县", "Quxian"),
            (3561, 1312, "宣汉县", "Xuanhan"),
            (3562, 1312, "开江县", "Kaijiang"),
            (3563, 1312, "大竹县", "Dazhu"),
            (3564, 1309, "巴州区", "Bazhou"),
            (3565, 1309, "南江县", "Nanjiang"),
            (3566, 1309, "平昌县", "Pingchang"),
            (3567, 1309, "通江县", "Tongjiang"),
            (3568, 1304, "雨城区", "Yucheng"),
            (3569, 1304, "芦山县", "Lushan"),
            (3570, 1304, "石棉县", "Shimian"),
            (3571, 1304, "名山县", "Mingshan"),
            (3572, 1304, "天全县", "Tianquan"),
            (3573, 1304, "荥经县", "Yingjing"),
            (3574, 1304, "宝兴县", "Baoxing"),
            (3575, 1304, "汉源县", "Hanyuan"),
            (3576, 1302, "东坡区", "Dongpo"),
            (3577, 1302, "仁寿县", "Renshou"),
            (3578, 1302, "彭山县", "Pengshan"),
            (3579, 1302, "洪雅县", "Hongya"),
            (3580, 1302, "丹棱县", "Danleng"),
            (3581, 1302, "青神县", "Qingshen"),
            (3582, 1317, "雁江区", "Yanjiang"),
            (3583, 1317, "简阳市", "Jianyang"),
            (3584, 1317, "安岳县", "Anyue"),
            (3585, 1317, "乐至县", "Lezhi"),
            (3586, 1310, "马尔康县", "Maerkang"),
            (3587, 1310, "九寨沟县", "Jiuzhaigou"),
            (3588, 1310, "红原县", "Hongyuan"),
            (3589, 1310, "汶川县", "Wenchuan"),
            (3590, 1310, "阿坝县", "Aba"),
            (3591, 1310, "理县", "Lixian"),
            (3592, 1310, "若尔盖县", "Ruoergai"),
            (3593, 1310, "小金县", "Xiaojin"),
            (3594, 1310, "黑水县", "Heishui"),
            (3595, 1310, "金川县", "Jinchuan"),
            (3596, 1310, "松潘县", "Songpan"),
            (3597, 1310, "壤塘县", "Rangtang"),
            (3598, 1310, "茂县", "Maoxian"),
            (3599, 1314, "康定县", "Kangding"),
            (3600, 1314, "丹巴县", "Danba"),
            (3601, 1314, "炉霍县", "Luhuo"),
            (3602, 1314, "九龙县", "Jiulong"),
            (3603, 1314, "甘孜县", "Ganzi"),
            (3604, 1314, "雅江县", "Yajiang"),
            (3605, 1314, "新龙县", "Xinlong"),
            (3606, 1314, "道孚县", "Daofu"),
            (3607, 1314, "白玉县", "Baiyu"),
            (3608, 1314, "理塘县", "Litang"),
            (3609, 1314, "德格县", "Dege"),
            (3610, 1314, "乡城县", "Xiangcheng"),
            (3611, 1314, "石渠县", "Shiqu"),
            (3612, 1314, "稻城县", "Daocheng"),
            (3613, 1314, "色达县", "Seda"),
            (3614, 1314, "巴塘县", "Batang"),
            (3615, 1314, "泸定县", "Luding"),
            (3616, 1314, "得荣县", "Derong"),
            (3617, 1301, "西昌市", "Xichang"),
            (3618, 1301, "美姑县", "Meigu"),
            (3619, 1301, "昭觉县", "Zhaojue"),
            (3620, 1301, "金阳县", "Jinyang"),
            (3621, 1301, "甘洛县", "Ganluo"),
            (3622, 1301, "布拖县", "Butuo"),
            (3623, 1301, "雷波县", "Leibo"),
            (3624, 1301, "普格县", "Puge"),
            (3625, 1301, "宁南县", "Ningnan"),
            (3626, 1301, "喜德县", "Xide"),
            (3627, 1301, "会东县", "Huidong"),
            (3628, 1301, "越西县", "Yuexi"),
            (3629, 1301, "会理县", "Huili"),
            (3630, 1301, "盐源县", "Yanyuan"),
            (3631, 1301, "德昌县", "Dechang"),
            (3632, 1301, "冕宁县", "Mianning"),
            (3633, 1301, "木里藏族自治县", "Muli"),
            (3634, 1117, "南明区", "Nanming"),
            (3635, 1117, "云岩区", "Yunyan"),
            (3636, 1117, "花溪区", "Huaxi"),
            (3637, 1117, "乌当区", "Wudang"),
            (3638, 1117, "白云区", "Baiyun"),
            (3639, 1117, "小河区", "Xiaohe"),
            (3640, 1117, "清镇市", "Qingzhen"),
            (3641, 1117, "开阳县", "Kaiyang"),
            (3642, 1117, "修文县", "Xiuwen"),
            (3643, 1117, "息烽县", "Xifeng"),
            (3644, 1110, "钟山区", "Zhongshan"),
            (3645, 1110, "水城县", "Shuicheng"),
            (3646, 1110, "盘县", "Panxian"),
            (3647, 1110, "六枝特区", "Xiuzhite"),
            (3648, 1118, "红花岗区", "Honghuagang"),
            (3649, 1118, "赤水市", "Chishui"),
            (3650, 1118, "仁怀市", "Renhuai"),
            (3651, 1118, "遵义县", "Zunyi"),
            (3652, 1118, "绥阳县", "Suiyang"),
            (3653, 1118, "桐梓县", "Tongzi"),
            (3654, 1118, "习水县", "Xishui"),
            (3655, 1118, "凤冈县", "Fenggang"),
            (3656, 1118, "正安县", "Zhengan"),
            (3657, 1118, "余庆县", "Yuqing"),
            (3658, 1118, "湄潭县", "Meitan"),
            (3659, 1118, "道真仡佬族苗族自治县", "Daozhen"),
            (3660, 1118, "务川仡佬族苗族自治县", "Wuchuan"),
            (3661, 1115, "西秀区", "Xixiu"),
            (3662, 1115, "普定县", "Puding"),
            (3663, 1115, "平坝县", "Pingba"),
            (3664, 1115, "镇宁布依族苗族自治县", "Zhenning"),
            (3665, 1115, "紫云苗族布依族自治县", "Ziyun"),
            (3666, 1115, "关岭布依族苗族自治县", "Guanling"),
            (3667, 1114, "铜仁市", "Tongren"),
            (3668, 1114, "德江县", "Dejiang"),
            (3669, 1114, "江口县", "Jiangkou"),
            (3670, 1114, "思南县", "Sinan"),
            (3671, 1114, "石阡县", "Shiqian"),
            (3672, 1114, "玉屏侗族自治县", "Yuping"),
            (3673, 1114, "松桃苗族自治县", "Songtao"),
            (3674, 1114, "印江土家族苗族自治县", "Yinjiang"),
            (3675, 1114, "沿河土家族自治县", "Yanhe"),
            (3676, 1114, "万山特区", "Wanshante"),
            (3677, 1116, "毕节市", "Bijie"),
            (3678, 1116, "黔西县", "Qianxi"),
            (3679, 1116, "大方县", "Dafang"),
            (3680, 1116, "织金县", "Zhijin"),
            (3681, 1116, "金沙县", "Jinsha"),
            (3682, 1116, "赫章县", "Hezhang"),
            (3683, 1116, "纳雍县", "Nayong"),
            (3684, 1116, "威宁彝族回族苗族自治县", "Weining"),
            (3685, 1111, "兴义市", "Xingyi"),
            (3686, 1111, "望谟县", "Wangmo"),
            (3687, 1111, "兴仁县", "Xingren"),
            (3688, 1111, "普安县", "Puan"),
            (3689, 1111, "册亨县", "Ceheng"),
            (3690, 1111, "晴隆县", "Qinglong"),
            (3691, 1111, "贞丰县", "Zhenfeng"),
            (3692, 1111, "安龙县", "Anlong"),
            (3693, 1113, "凯里市", "Kaili"),
            (3694, 1113, "施秉县", "Shibing"),
            (3695, 1113, "从江县", "Congjiang"),
            (3696, 1113, "锦屏县", "Jinping"),
            (3697, 1113, "镇远县", "Zhenyuan"),
            (3698, 1113, "麻江县", "Majiang"),
            (3699, 1113, "台江县", "Taijiang"),
            (3700, 1113, "天柱县", "Tianzhu"),
            (3701, 1113, "黄平县", "Huangping"),
            (3702, 1113, "榕江县", "Rongjiang"),
            (3703, 1113, "剑河县", "Jianhe"),
            (3704, 1113, "三穗县", "Sansui"),
            (3705, 1113, "雷山县", "Leishan"),
            (3706, 1113, "黎平县", "Liping"),
            (3707, 1113, "岑巩县", "Cengong"),
            (3708, 1113, "丹寨县", "Danzhai"),
            (3709, 1112, "都匀市", "Duyun"),
            (3710, 1112, "贵定县", "Guiding"),
            (3711, 1112, "惠水县", "Huishui"),
            (3712, 1112, "罗甸县", "Luodian"),
            (3713, 1112, "瓮安县", "Wenan"),
            (3714, 1112, "荔波县", "Libo"),
            (3715, 1112, "龙里县", "Longli"),
            (3716, 1112, "平塘县", "Pingtang"),
            (3717, 1112, "长顺县", "Changshun"),
            (3718, 1112, "独山县", "Dushan"),
            (3719, 1112, "三都水族自治县", "Sandu"),
            (3720, 1340, "盘龙区", "Panlong"),
            (3721, 1340, "五华区", "Wuhua"),
            (3722, 1340, "官渡区", "Guandu"),
            (3723, 1340, "西山区", "Xishan"),
            (3724, 1340, "东川区", "Dongchuan"),
            (3725, 1340, "安宁市", "Anning"),
            (3726, 1340, "富民县", "Fumin"),
            (3727, 1340, "嵩明县", "Songming"),
            (3728, 1340, "呈贡县", "Chenggong"),
            (3729, 1340, "晋宁县", "Jinning"),
            (3730, 1340, "宜良县", "Yiliang"),
            (3731, 1340, "禄劝彝族苗族自治县", "Luquan"),
            (3732, 1340, "石林彝族自治县", "Shilin"),
            (3733, 1340, "寻甸回族自治县", "Xundian"),
            (3734, 1342, "麒麟区", "Qilin"),
            (3735, 1342, "宣威市", "Xuanwei"),
            (3736, 1342, "陆良县", "Luliang"),
            (3737, 1342, "会泽县", "Huize"),
            (3738, 1342, "富源县", "Fuyuan"),
            (3739, 1342, "罗平县", "Luoping"),
            (3740, 1342, "马龙县", "Malong"),
            (3741, 1342, "师宗县", "Shizong"),
            (3742, 1342, "沾益县", "Zhanyi"),
            (3743, 1346, "红塔区", "Hongta"),
            (3744, 1346, "华宁县", "Huaning"),
            (3745, 1346, "澄江县", "Chengjiang"),
            (3746, 1346, "易门县", "Yimen"),
            (3747, 1346, "通海县", "Tonghai"),
            (3748, 1346, "江川县", "Jiangchuan"),
            (3749, 1346, "元江哈尼族彝族傣族自治县", "Yuanjiang"),
            (3750, 1346, "新平彝族傣族自治县", "Xinping"),
            (3751, 1346, "峨山彝族自治县", "Eshan"),
            (3752, 1348, "隆阳区", "Longyang"),
            (3753, 1348, "施甸县", "Shidian"),
            (3754, 1348, "昌宁县", "Changning"),
            (3755, 1348, "龙陵县", "Longling"),
            (3756, 1348, "腾冲县", "Tengchong"),
            (3757, 1345, "昭阳区", "Zhaoyang"),
            (3758, 1345, "永善县", "Yongshan"),
            (3759, 1345, "绥江县", "Suijiang"),
            (3760, 1345, "镇雄县", "Zhenxiong"),
            (3761, 1345, "大关县", "Daguan"),
            (3762, 1345, "盐津县", "Yanjin"),
            (3763, 1345, "巧家县", "Qiaojia"),
            (3764, 1345, "彝良县", "Yiliang"),
            (3765, 1345, "威信县", "Weixin"),
            (3766, 1345, "水富县", "Shuifu"),
            (3767, 1345, "鲁甸县", "Ludian"),
            (3768, 1343, "普洱哈尼族彝族自治县", "Puer"),
            (3769, 1343, "景东彝族自治县", "Jingdong"),
            (3770, 1343, "镇沅彝族哈尼族拉祜族自治县", "Zhenyuan"),
            (3771, 1343, "景谷彝族傣族自治县", "Jinggu"),
            (3772, 1343, "墨江哈尼族自治县", "Mojiang"),
            (3773, 1343, "澜沧拉祜族自治县", "Lancang"),
            (3774, 1343, "西盟佤族自治县", "Ximeng"),
            (3775, 1343, "江城哈尼族彝族自治县", "Jiangcheng"),
            (3776, 1343, "孟连傣族拉祜族佤族自治县", "Menglian"),
            (3777, 1343, "翠云区", "Cuiyun"),
            (3778, 1338, "临沧县", "Lincang"),
            (3779, 1338, "镇康县", "Zhenkang"),
            (3780, 1338, "凤庆县", "Fengqing"),
            (3781, 1338, "云县", "Yunxian"),
            (3782, 1338, "永德县", "Yongde"),
            (3783, 1338, "双江拉祜族佤族布朗族傣族自治县", "Shuangjiang"),
            (3784, 1338, "沧源佤族自治县", "Cangyuan"),
            (3785, 1338, "耿马傣族佤族治县", "Gengma"),
            (3786, 1339, "古城区", "Gucheng"),
            (3787, 1339, "华坪县", "Huaping"),
            (3788, 1339, "永胜县", "Yongsheng"),
            (3789, 1339, "玉龙纳西族自治县", "Yulong"),
            (3790, 1339, "宁蒗彝族自治县", "Ninglang"),
            (3791, 1344, "文山县", "Wenshan"),
            (3792, 1344, "麻栗坡县", "Malipo"),
            (3793, 1344, "砚山县", "Yanshan"),
            (3794, 1344, "广南县", "Guangnan"),
            (3795, 1344, "马关县", "Maguan"),
            (3796, 1344, "富宁县", "Funing"),
            (3797, 1344, "西畴县", "Xichou"),
            (3798, 1344, "丘北县", "Qiubei"),
            (3799, 1352, "个旧市", "Gejiu"),
            (3800, 1352, "开远市", "Kaiyuan"),
            (3801, 1352, "弥勒县", "Mile"),
            (3802, 1352, "红河县", "Honghe"),
            (3803, 1352, "绿春县", "Lvchun"),
            (3804, 1352, "蒙自县", "Mengzi"),
            (3805, 1352, "泸西县", "Luxi"),
            (3806, 1352, "建水县", "Jianshui"),
            (3807, 1352, "元阳县", "Yuanyang"),
            (3808, 1352, "石屏县", "Shiping"),
            (3809, 1352, "金平苗族瑶族傣族自治县", "Jinping"),
            (3810, 1352, "河口瑶族自治县", "Hekou"),
            (3811, 1352, "屏边苗族自治县", "Pingbian"),
            (3812, 1353, "景洪市", "Jinghong"),
            (3813, 1353, "勐海县", "Menghai"),
            (3814, 1353, "勐腊县", "Mengla"),
            (3815, 1349, "楚雄市", "Chuxiong"),
            (3816, 1349, "元谋县", "Yuanmou"),
            (3817, 1349, "南华县", "Nanhua"),
            (3818, 1349, "牟定县", "Mouding"),
            (3819, 1349, "武定县", "Wuding"),
            (3820, 1349, "大姚县", "Dayao"),
            (3821, 1349, "双柏县", "Shuangbai"),
            (3822, 1349, "禄丰县", "Lufeng"),
            (3823, 1349, "永仁县", "Yongren"),
            (3824, 1349, "姚安县", "Yaoan"),
            (3825, 1350, "大理市", "Dali"),
            (3826, 1350, "剑川县", "Jianchuan"),
            (3827, 1350, "弥渡县", "Midu"),
            (3828, 1350, "云龙县", "Yunlong"),
            (3829, 1350, "洱源县", "Eryuan"),
            (3830, 1350, "鹤庆县", "Heqing"),
            (3831, 1350, "祥云县", "Xiangyun"),
            (3832, 1350, "宾川县", "Binchuan"),
            (3833, 1350, "永平县", "Yongping"),
            (3834, 1350, "漾濞彝族自治县", "Yangbi"),
            (3835, 1350, "巍山彝族回族自治县", "Weishan"),
            (3836, 1350, "南涧彝族自治县", "Nanjian"),
            (3837, 1341, "潞西市", "Luxi"),
            (3838, 1341, "瑞丽市", "Ruili"),
            (3839, 1341, "盈江县", "Yingjiang"),
            (3840, 1341, "梁河县", "Lianghe"),
            (3841, 1341, "陇川县", "Longchuan"),
            (3842, 1347, "泸水县", "Lushui"),
            (3843, 1347, "福贡县", "Fugong"),
            (3844, 1347, "兰坪白族普米族自治县", "Lanping"),
            (3845, 1347, "贡山独龙族怒族自治县", "Gongshan"),
            (3846, 1351, "香格里拉县", "Xianggelila"),
            (3847, 1351, "德钦县", "Deqin"),
            (3848, 1351, "维西傈僳族自治县", "Weixi"),
            (3849, 1320, "城关区", "Chengguan"),
            (3850, 1320, "林周县", "Linzhou"),
            (3851, 1320, "达孜县", "Dazi"),
            (3852, 1320, "尼木县", "Nimu"),
            (3853, 1320, "当雄县", "Dangxiong"),
            (3854, 1320, "曲水县", "Qushui"),
            (3855, 1320, "墨竹工卡县", "Mozhugongka"),
            (3856, 1320, "堆龙德庆县", "Duilongdeqing"),
            (3857, 1323, "那曲县", "Naqu"),
            (3858, 1323, "嘉黎县", "Jiali"),
            (3859, 1323, "申扎县", "Shenzha"),
            (3860, 1323, "巴青县", "Baqing"),
            (3861, 1323, "聂荣县", "Nierong"),
            (3862, 1323, "尼玛县", "Nima"),
            (3863, 1323, "比如县", "Biru"),
            (3864, 1323, "索县", "Suoxian"),
            (3865, 1323, "班戈县", "Bange"),
            (3866, 1323, "安多县", "Anduo"),
            (3867, 1325, "昌都县", "Changdu"),
            (3868, 1325, "芒康县", "Mangkang"),
            (3869, 1325, "贡觉县", "Gongjue"),
            (3870, 1325, "八宿县", "Basu"),
            (3871, 1325, "左贡县", "Zuogong"),
            (3872, 1325, "边坝县", "Bianba"),
            (3873, 1325, "洛隆县", "Luolong"),
            (3874, 1325, "江达县", "Jiangda"),
            (3875, 1325, "类乌齐县", "Leiwuqi"),
            (3876, 1325, "丁青县", "Dingqing"),
            (3877, 1325, "察雅县", "Chaya"),
            (3878, 1322, "乃东县", "Naidong"),
            (3879, 1322, "琼结县", "Qiongjie"),
            (3880, 1322, "措美县", "Cuomei"),
            (3881, 1322, "加查县", "Jiacha"),
            (3882, 1322, "贡嘎县", "Gongga"),
            (3883, 1322, "洛扎县", "Luozha"),
            (3884, 1322, "曲松县", "Qusong"),
            (3885, 1322, "桑日县", "Sangri"),
            (3886, 1322, "扎囊县", "Zhanang"),
            (3887, 1322, "错那县", "Cuona"),
            (3888, 1322, "隆子县", "Longzi"),
            (3889, 1322, "浪卡子县", "Langkazi"),
            (3890, 1321, "日喀则市", "Rikaze"),
            (3891, 1321, "定结县", "Dingjie"),
            (3892, 1321, "萨迦县", "Sajia"),
            (3893, 1321, "江孜县", "Jiangzi"),
            (3894, 1321, "拉孜县", "Lazi"),
            (3895, 1321, "定日县", "Dingri"),
            (3896, 1321, "康马县", "Kangma"),
            (3897, 1321, "聂拉木县", "Nielamu"),
            (3898, 1321, "吉隆县", "Jilong"),
            (3899, 1321, "亚东县", "Yadong"),
            (3900, 1321, "谢通门县", "Xiedongmen"),
            (3901, 1321, "昂仁县", "Angren"),
            (3902, 1321, "岗巴县", "Gangba"),
            (3903, 1321, "仲巴县", "Zhongba"),
            (3904, 1321, "萨嘎县", "Saga"),
            (3905, 1321, "仁布县", "Renbu"),
            (3906, 1321, "白朗县", "Bailang"),
            (3907, 1321, "南木林县", "Nanmulin"),
            (3908, 1324, "噶尔县", "Gaer"),
            (3909, 1324, "措勤县", "Cuoqin"),
            (3910, 1324, "普兰县", "Pulan"),
            (3911, 1324, "革吉县", "Geji"),
            (3912, 1324, "日土县", "Ritu"),
            (3913, 1324, "札达县", "Zhada"),
            (3914, 1324, "改则县", "Gaize"),
            (3915, 1319, "林芝县", "Linzhi"),
            (3916, 1319, "墨脱县", "Motuo"),
            (3917, 1319, "朗县", "Langxian"),
            (3918, 1319, "米林县", "Milin"),
            (3919, 1319, "察隅县", "Chaou"),
            (3920, 1319, "波密县", "Bomi"),
            (3921, 1319, "工布江达县", "Gongbujiangda"),
            (3922, 1292, "莲湖区", "Lianhu"),
            (3923, 1292, "新城区", "Xincheng"),
            (3924, 1292, "碑林区", "Beilin"),
            (3925, 1292, "雁塔区", "Yanta"),
            (3926, 1292, "灞桥区", "Baqiao"),
            (3927, 1292, "未央区", "Weiyang"),
            (3928, 1292, "阎良区", "Yanliang"),
            (3929, 1292, "临潼区", "Lintong"),
            (3930, 1292, "长安县", "Changan"),
            (3931, 1292, "高陵县", "Gaoling"),
            (3932, 1292, "蓝田县", "Lantian"),
            (3933, 1292, "户县", "Huxian"),
            (3934, 1292, "周至县", "Zhouzhi"),
            (3935, 1290, "王益区", "Wangyi"),
            (3936, 1290, "印台区", "Yintai"),
            (3937, 1290, "耀县", "Yaoxian"),
            (3938, 1290, "宜君县", "Yijun"),
            (3939, 1296, "渭滨区", "Weibin"),
            (3940, 1296, "金台区", "Jintai"),
            (3941, 1296, "宝鸡县", "Baoji"),
            (3942, 1296, "岐山县", "Qishan"),
            (3943, 1296, "凤翔县", "Fengxiang"),
            (3944, 1296, "陇县", "Longxian"),
            (3945, 1296, "太白县", "Taibai"),
            (3946, 1296, "麟游县", "Linyou"),
            (3947, 1296, "扶风县", "Fufeng"),
            (3948, 1296, "千阳县", "Qianyang"),
            (3949, 1296, "眉县", "Meixian"),
            (3950, 1296, "凤县", "Fengxian"),
            (3951, 1289, "秦都区", "Qindu"),
            (3952, 1289, "渭城区", "Weicheng"),
            (3953, 1289, "杨陵区", "Yangling"),
            (3954, 1289, "兴平市", "Xingping"),
            (3955, 1289, "礼泉县", "Liquan"),
            (3956, 1289, "泾阳县", "Jingyang"),
            (3957, 1289, "永寿县", "Yongshou"),
            (3958, 1289, "三原县", "Sanyuan"),
            (3959, 1289, "彬县", "Binxian"),
            (3960, 1289, "旬邑县", "Xunyi"),
            (3961, 1289, "长武县", "Changwu"),
            (3962, 1289, "乾县", "Qianxian"),
            (3963, 1289, "武功县", "Wugong"),
            (3964, 1289, "淳化县", "Chunhua"),
            (3965, 1291, "临渭区", "Linwei"),
            (3966, 1291, "韩城市", "Hancheng"),
            (3967, 1291, "华阴市", "Huayin"),
            (3968, 1291, "蒲城县", "Pucheng"),
            (3969, 1291, "潼关县", "Tongguan"),
            (3970, 1291, "白水县", "Baishui"),
            (3971, 1291, "澄城县", "Chengcheng"),
            (3972, 1291, "华县", "Huaxian"),
            (3973, 1291, "合阳县", "Heyang"),
            (3974, 1291, "合阳县", "Heyang"),
            (3975, 1291, "大荔县", "Dali"),
            (3976, 1293, "宝塔区", "Baota"),
            (3977, 1293, "安塞县", "Ansai"),
            (3978, 1293, "洛川县", "Luochuan"),
            (3979, 1293, "子长县", "Zichang"),
            (3980, 1293, "黄陵县", "Huangling"),
            (3981, 1293, "延长县", "Yanchang"),
            (3982, 1293, "甘泉县", "Ganquan"),
            (3983, 1293, "宜川县", "Yichuan"),
            (3984, 1293, "志丹县", "Zhidan"),
            (3985, 1293, "黄龙县", "Huanglong"),
            (3986, 1293, "吴旗县", "Wuqi"),
            (3987, 1293, "延川县", "Yanchuan"),
            (3988, 1293, "富县", "Fuxian"),
            (3989, 1297, "汉台区", "Hantai"),
            (3990, 1297, "留坝县", "Liuba"),
            (3991, 1297, "镇巴县", "Zhenba"),
            (3992, 1297, "城固县", "Chenggu"),
            (3993, 1297, "南郑县", "Nanzheng"),
            (3994, 1297, "洋县", "Yangxian"),
            (3995, 1297, "宁强县", "Ningqiang"),
            (3996, 1297, "佛坪县", "Foping"),
            (3997, 1297, "勉县", "Mianxian"),
            (3998, 1297, "西乡县", "Xixiang"),
            (3999, 1297, "略阳县", "Lueyang"),
            (4000, 1294, "榆阳区", "Yuyang"),
            (4001, 1294, "清涧县", "Qingjian"),
            (4002, 1294, "绥德县", "Suide"),
            (4003, 1294, "神木县", "Shenmu"),
            (4004, 1294, "佳县", "Jiaxian"),
            (4005, 1294, "府谷县", "Fugu"),
            (4006, 1294, "子洲县", "Zizhou"),
            (4007, 1294, "靖边县", "Jingbian"),
            (4008, 1294, "横山县", "Hengshan"),
            (4009, 1294, "米脂县", "Mizhi"),
            (4010, 1294, "吴堡县", "Wubao"),
            (4011, 1294, "定边县", "Dingbian"),
            (4012, 1295, "汉滨区", "Hanbin"),
            (4013, 1295, "紫阳县", "Ziyang"),
            (4014, 1295, "岚皋县", "Langao"),
            (4015, 1295, "旬阳县", "Xuyang"),
            (4016, 1295, "镇坪县", "Zhenping"),
            (4017, 1295, "平利县", "Pingli"),
            (4018, 1295, "石泉县", "Shiquan"),
            (4019, 1295, "宁陕县", "Ningshan"),
            (4020, 1295, "白河县", "Baihe"),
            (4021, 1295, "汉阴县", "Hanyin"),
            (4022, 1288, "商州区", "Shangzhou"),
            (4023, 1288, "镇安县", "Zhenan"),
            (4024, 1288, "山阳县", "Shanyang"),
            (4025, 1288, "洛南县", "Luonan"),
            (4026, 1288, "商南县", "Shangnan"),
            (4027, 1288, "丹凤县", "Danfeng"),
            (4028, 1288, "柞水县", "Zhashui"),
            (4031, 1062, "城关区", "Chengguan"),
            (4032, 1062, "七里河区", "Qilihe"),
            (4033, 1062, "西固区", "Xigu"),
            (4034, 1062, "安宁区", "Anning"),
            (4035, 1062, "红古区", "Honggu"),
            (4036, 1062, "永登县", "Yongdeng"),
            (4037, 1062, "榆中县", "Yuzhong"),
            (4038, 1062, "皋兰县", "Gaolan"),
            (4039, 1072, "金川区", "Jinchuan"),
            (4040, 1072, "永昌县", "Yongchang"),
            (4041, 1068, "白银区", "Baiyin"),
            (4042, 1068, "平川区", "Pingchuan"),
            (4043, 1068, "靖远县", "Jingyuan"),
            (4044, 1068, "靖远县", "Jingyuan"),
            (4045, 1068, "会宁县", "Huining"),
            (4046, 1063, "秦城区", "Qincheng"),
            (4047, 1063, "北道区", "Beidao"),
            (4048, 1063, "武山县", "Wushan"),
            (4049, 1063, "甘谷县", "Gangu"),
            (4050, 1063, "清水县", "Qingshui"),
            (4051, 1063, "秦安县", "Qinan"),
            (4052, 1063, "张家川回族自治县", "Zhangjiachuan"),
            (4053, 1071, "嘉峪关市", "Jiayuguan"),
            (4054, 1064, "凉州区", "Liangzhou"),
            (4055, 1064, "民勤县", "Minqin"),
            (4056, 1064, "古浪县", "Gulang"),
            (4057, 1064, "天祝藏族自治县", "Tianzhu"),
            (4058, 1069, "定西区", "Dingxi"),
            (4059, 1069, "岷县", "Minxian"),
            (4060, 1069, "渭源县", "Weiyuan"),
            (4061, 1069, "陇西县", "Longxi"),
            (4062, 1069, "通渭县", "Tongwei"),
            (4063, 1069, "漳县", "Zhangxian"),
            (4064, 1069, "临洮县", "Lintao"),
            (4065, 1067, "崆峒区", "Kongtong"),
            (4066, 1067, "灵台县", "Lingtai"),
            (4067, 1067, "静宁县", "Jingning"),
            (4068, 1067, "崇信县", "Chongxin"),
            (4069, 1067, "华亭县", "Huating"),
            (4070, 1067, "泾川县", "Jingchuan"),
            (4071, 1067, "庄浪县", "Zhuanglang"),
            (4072, 1065, "西峰区", "Xifeng"),
            (4073, 1065, "庆城县", "Qingcheng"),
            (4074, 1065, "镇原县", "Zhenyuan"),
            (4075, 1065, "环县", "Huanxian"),
            (4076, 1065, "华池县", "Huachi"),
            (4077, 1065, "合水县", "Heshui"),
            (4078, 1065, "宁县", "Ningxian"),
            (4079, 1065, "正宁县", "Zhengning"),
            (4080, 1061, "成县", "Chengxian"),
            (4081, 1061, "礼县", "Lixian"),
            (4082, 1061, "康县", "Kangxian"),
            (4083, 1061, "武都县", "Wudu"),
            (4084, 1061, "文县", "Wenxian"),
            (4085, 1061, "两当县", "Liangdang"),
            (4086, 1061, "徽县", "Huixian"),
            (4087, 1061, "宕昌县", "Dangchang"),
            (4088, 1061, "西和县", "Xihe"),
            (4089, 1066, "甘州区", "Ganzhou"),
            (4090, 1066, "民乐县", "Minle"),
            (4091, 1066, "山丹县", "Shandan"),
            (4092, 1066, "临泽县", "Linze"),
            (4093, 1066, "高台县", "Gaotai"),
            (4094, 1066, "肃南裕固族自治县", "Sunan"),
            (4095, 4029, "玉门市", "Yumen"),
            (4096, 4030, "敦煌市", "Dunhuang"),
            (4097, 1073, "肃州区", "Suzhou"),
            (4098, 1073, "安西县", "Anxi"),
            (4099, 1073, "金塔县", "Jinta"),
            (4100, 1073, "阿克塞哈萨克族自治县", "Akesai"),
            (4101, 1073, "肃北蒙古族自治县", "Subei"),
            (4102, 1070, "合作市", "Hezuo"),
            (4103, 1070, "临潭县", "Lintan"),
            (4104, 1070, "卓尼县", "Zhuoni"),
            (4105, 1070, "舟曲县", "Zhouqu"),
            (4106, 1070, "迭部县", "Diebu"),
            (4107, 1070, "玛曲县", "Maqu"),
            (4108, 1070, "碌曲县", "Luqu"),
            (4109, 1070, "夏河县", "Xiahe"),
            (4110, 1060, "临夏市", "Linxia"),
            (4111, 1060, "临夏县", "Linxia"),
            (4112, 1060, "康乐县", "Kangle"),
            (4113, 1060, "永靖县", "Yongjing"),
            (4114, 1060, "广河县", "Guanghe"),
            (4115, 1060, "和政县", "Hezheng"),
            (4116, 1060, "东乡族自治县", "Dongxiang"),
            (4117, 1060, "积石山保安族东乡族撒拉族自治县", "Jishishan"),
            (4118, 1252, "城中区", "Chengzhong"),
            (4119, 1252, "城东区", "Chengdong"),
            (4120, 1252, "城西区", "Chengxi"),
            (4121, 1252, "城北区", "Chengbei"),
            (4122, 1252, "湟源县", "Huangyuan"),
            (4123, 1252, "湟中县", "Huangzhong"),
            (4124, 1252, "大通回族土族自治县", "Datong"),
            (4125, 1258, "平安县", "Pingan"),
            (4126, 1258, "乐都县", "Ledu"),
            (4127, 1258, "民和回族土族自治县", "Minhe"),
            (4128, 1258, "互助土族自治县", "Huzhu"),
            (4129, 1258, "化隆回族自治县", "Hualong"),
            (4130, 1258, "循化撒拉族自治县", "Xunhua"),
            (4131, 1257, "海晏县", "Haiyan"),
            (4132, 1257, "祁连县", "Qilian"),
            (4133, 1257, "刚察县", "Gangcha"),
            (4134, 1257, "门源回族自治县", "Menyuan"),
            (4135, 1259, "同仁县", "Tongren"),
            (4136, 1259, "泽库县", "Zeku"),
            (4137, 1259, "尖扎县", "Jianzha"),
            (4138, 1259, "河南蒙古族自治县", "Henan"),
            (4139, 1256, "共和县", "Gonghe"),
            (4140, 1256, "同德县", "Tongde"),
            (4141, 1256, "贵德县", "Guide"),
            (4142, 1256, "兴海县", "Xinghai"),
            (4143, 1256, "贵南县", "Guinan"),
            (4144, 1254, "玛沁县", "Maqin"),
            (4145, 1254, "班玛县", "Banma"),
            (4146, 1254, "甘德县", "Gande"),
            (4147, 1254, "达日县", "Dari"),
            (4148, 1254, "久治县", "Jiuzhi"),
            (4149, 1254, "玛多县", "Maduo"),
            (4150, 1253, "玉树县", "Yushu"),
            (4151, 1253, "杂多县", "Zaduo"),
            (4152, 1253, "称多县", "Chengduo"),
            (4153, 1253, "治多县", "Zhiduo"),
            (4154, 1253, "囊谦县", "Nangqian"),
            (4155, 1253, "曲麻莱县", "Qumalai"),
            (4156, 1255, "德令哈市", "Delingha"),
            (4157, 1255, "格尔木市", "Geermu"),
            (4158, 1255, "乌兰县", "Wulan"),
            (4159, 1255, "天峻县", "Tianjun"),
            (4160, 1255, "都兰县", "Dulan"),
            (4161, 1250, "西夏区", "Xixia"),
            (4162, 1250, "金凤区", "Jinfeng"),
            (4163, 1250, "兴庆区", "Xingqing"),
            (4164, 1250, "永宁县", "Yongning"),
            (4165, 1250, "贺兰县", "Helan"),
            (4166, 1248, "大武口区", "Dawukou"),
            (4167, 1248, "惠农区", "Huinong"),
            (4168, 1248, "石炭井区", "Shitanjing"),
            (4169, 1248, "平罗县", "Pingluo"),
            (4170, 1249, "利通区", "Litong"),
            (4171, 1249, "青铜峡市", "Qingtongxia"),
            (4172, 1249, "灵武市", "Lingwu"),
            (4173, 1249, "同心县", "Tongxin"),
            (4174, 1249, "盐池县", "Yanchi"),
            (4175, 1249, "中卫县", "Zhongwei"),
            (4176, 1249, "中宁县", "Zhongning"),
            (4177, 1251, "原州区", "Yuanzhou"),
            (4178, 1251, "海原县", "Haiyuan"),
            (4179, 1251, "西吉县", "Xiji"),
            (4180, 1251, "隆德县", "Longde"),
            (4181, 1251, "泾源县", "Jingyuan"),
            (4182, 1251, "彭阳县", "Pengyang"),
            (4183, 1327, "天山区", "Tianshan"),
            (4184, 1327, "沙依巴克区", "Shanongbake"),
            (4185, 1327, "新市区", "Xinshi"),
            (4186, 1327, "水磨沟区", "Shuimogou"),
            (4187, 1327, "头屯河区", "Toutunhe"),
            (4188, 1327, "达坂城区", "Dabancheng"),
            (4189, 1327, "东山区", "Dongshan"),
            (4190, 1327, "乌鲁木齐县", "Mulumuqi"),
            (4191, 1336, "克拉玛依区", "Kelamayi"),
            (4192, 1336, "独山子区", "Dushanzi"),
            (4193, 1336, "白碱滩区", "Baijiantan"),
            (4194, 1336, "乌尔禾区", "Wuerhe"),
            (4195, 1365, "石河子市", "Shihezi"),
            (4196, 1366, "阿拉尔市", "Alaer"),
            (4197, 1367, "图木舒克市", "Tumushuke"),
            (4198, 1368, "五家渠市", "Wujiaqu"),
            (4199, 1326, "吐鲁番市", "Tulufan"),
            (4200, 1326, "托克逊县", "Tuokexun"),
            (4201, 1326, "鄯善县", "Shanshan"),
            (4202, 1333, "哈密市", "Hami"),
            (4203, 1333, "伊吾县", "Yiwu"),
            (4204, 1333, "巴里坤哈萨克自治县", "Balikun"),
            (4205, 1334, "和田市", "Hetian"),
            (4206, 1334, "和田县", "Hetian"),
            (4207, 1334, "洛浦县", "Luopu"),
            (4208, 1334, "民丰县", "Minfeng"),
            (4209, 1334, "皮山县", "Pishan"),
            (4210, 1334, "策勒县", "Cele"),
            (4211, 1334, "于田县", "Yutian"),
            (4212, 1334, "墨玉县", "Moyu"),
            (4213, 1330, "阿克苏市", "Akesu"),
            (4214, 1330, "温宿县", "Wensu"),
            (4215, 1330, "沙雅县", "Shaya"),
            (4216, 1330, "拜城县", "Baicheng"),
            (4217, 1330, "阿瓦提县", "Awati"),
            (4218, 1330, "库车县", "Kuche"),
            (4219, 1330, "柯坪县", "Keping"),
            (4220, 1330, "新和县", "Xinhe"),
            (4221, 1330, "乌什县", "Wushi"),
            (4222, 1337, "喀什市", "Kashi"),
            (4223, 1337, "巴楚县", "Bachu"),
            (4224, 1337, "泽普县", "Zepu"),
            (4225, 1337, "伽师县", "Jiashi"),
            (4226, 1337, "叶城县", "Yecheng"),
            (4227, 1337, "岳普湖县", "Yuepuhu"),
            (4228, 1337, "疏勒县", "Shule"),
            (4229, 1337, "麦盖提县", "Maigaiti"),
            (4230, 1337, "英吉沙县", "Yingjisha"),
            (4231, 1337, "莎车县", "Shache"),
            (4232, 1337, "疏附县", "Shufu"),
            (4233, 1337, "塔什库尔干塔吉克自治县", "Tashikuergantajike"),
            (4234, 1329, "阿图什市", "Atushi"),
            (4235, 1329, "阿合奇县", "Aheqi"),
            (4236, 1329, "乌恰县", "Wuqia"),
            (4237, 1329, "阿克陶县", "Aketao"),
            (4238, 1335, "库尔勒市", "Kuerle"),
            (4239, 1335, "和静县", "Hejing"),
            (4240, 1335, "尉犁县", "Weili"),
            (4241, 1335, "和硕县", "Heshuo"),
            (4242, 1335, "且末县", "Qiemo"),
            (4243, 1335, "博湖县", "Bohu"),
            (4244, 1335, "轮台县", "Luntai"),
            (4245, 1335, "若羌县", "Ruoqiang"),
            (4246, 1335, "焉耆回族自治县", "Yanqi"),
            (4247, 1331, "昌吉市", "Changji"),
            (4248, 1331, "阜康市", "Fukang"),
            (4249, 1331, "米泉市", "Miquan"),
            (4250, 1331, "奇台县", "Qitai"),
            (4251, 1331, "玛纳斯县", "Manasi"),
            (4252, 1331, "吉木萨尔县", "Jimusaer"),
            (4253, 1331, "呼图壁县", "Hutubi"),
            (4254, 1331, "木垒哈萨克自治县", "Mulei"),
            (4255, 1332, "博乐市", "Bole"),
            (4256, 1332, "精河县", "Jinghe"),
            (4257, 1332, "温泉县", "Wenquan"),
            (4258, 1328, "伊宁市", "Yining"),
            (4259, 1328, "奎屯市", "Kuitun"),
            (4260, 1328, "伊宁县", "Yining"),
            (4261, 1328, "特克斯县", "Tekesi"),
            (4262, 1328, "尼勒克县", "Nileke"),
            (4263, 1328, "昭苏县", "Zhaosu"),
            (4264, 1328, "新源县", "Xinyuan"),
            (4265, 1328, "霍城县", "Huocheng"),
            (4266, 1328, "巩留县", "Gongliu"),
            (4267, 1328, "察布查尔锡伯自治县", "Chabuchaer"),
            (4268, 1328, "塔城地区", "Tacheng"),
            (4270, 1373, "香港", "Hongkong"),
            (4271, 1374, "澳门", "Macao"),
            (4272, 1375, "台湾", "Taiwan"),
            (4275, 4274, "国外", "Abroad"),
        ]
        for c in cs:
            im = self.add_county(int(c[0]), int(c[1]), str(c[2]), str(c[3]))
            if im.error:
                return im
        return im
            
